@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "CppDocument.h"
 #include "FastPreprocessor.h"
@@ -22,10 +22,10 @@
 #include <cplusplus/TypeVisitor.h>
 #include <cplusplus/CoreTypes.h>
 
-#include <QBitArray>
+#include <utils/algorithm.h>
+
 #include <QByteArray>
 #include <QDebug>
-#include <QDir>
 #include <QFutureInterface>
 #include <QStack>
 
@@ -35,6 +35,7 @@
 */
 
 using namespace CPlusPlus;
+using namespace Utils;
 
 namespace {
 
@@ -205,7 +206,7 @@ public:
 
         const QString fileName = QString::fromUtf8(fileId->chars(), fileId->size());
 
-        if (fileName != doc->fileName())
+        if (fileName != doc->filePath().pathView())
             return;
 
         const QString message = QString::vasprintf(format, ap);
@@ -220,7 +221,7 @@ public:
         }
 #endif // DO_NOT_DUMP_ALL_PARSER_ERRORS
 
-        Document::DiagnosticMessage m(convertLevel(level), doc->fileName(),
+        Document::DiagnosticMessage m(convertLevel(level), doc->filePath(),
                                       line, column, message);
         messages->append(m);
     }
@@ -243,8 +244,8 @@ private:
 } // anonymous namespace
 
 
-Document::Document(const QString &fileName)
-    : _fileName(QDir::cleanPath(fileName)),
+Document::Document(const FilePath &filePath)
+    : _filePath(filePath),
       _globalNamespace(nullptr),
       _revision(0),
       _editorRevision(0),
@@ -254,9 +255,9 @@ Document::Document(const QString &fileName)
 
     _control->setDiagnosticClient(new DocumentDiagnosticClient(this, &_diagnosticMessages));
 
-    const QByteArray localFileName = fileName.toUtf8();
+    const QByteArray localFileName = filePath.path().toUtf8();
     const StringLiteral *fileId = _control->stringLiteral(localFileName.constData(),
-                                                                      localFileName.size());
+                                                          localFileName.size());
     _translationUnit = new TranslationUnit(_control, fileId);
     _translationUnit->setLanguageFeatures(LanguageFeatures::defaultFeatures());
 }
@@ -296,12 +297,12 @@ void Document::setLastModified(const QDateTime &lastModified)
     _lastModified = lastModified;
 }
 
-QStringList Document::includedFiles() const
+FilePaths Document::includedFiles() const
 {
-    QStringList files;
+    FilePaths files;
     for (const Include &i : std::as_const(_resolvedIncludes))
         files.append(i.resolvedFileName());
-    files.removeDuplicates();
+    FilePath::removeDuplicates(files);
     return files;
 }
 
@@ -517,9 +518,9 @@ const Document::UndefinedMacroUse *Document::findUndefinedMacroUseAt(int utf16ch
     return nullptr;
 }
 
-Document::Ptr Document::create(const QString &fileName)
+Document::Ptr Document::create(const FilePath &filePath)
 {
-    Document::Ptr doc(new Document(fileName));
+    Document::Ptr doc(new Document(filePath));
     return doc;
 }
 
@@ -652,7 +653,7 @@ bool Document::DiagnosticMessage::operator==(const Document::DiagnosticMessage &
             _column == other._column &&
             _length == other._length &&
             _level == other._level &&
-            _fileName == other._fileName &&
+            _filePath == other._filePath &&
             _text == other._text;
 }
 
@@ -679,25 +680,25 @@ bool Snapshot::isEmpty() const
     return _documents.isEmpty();
 }
 
-Snapshot::const_iterator Snapshot::find(const Utils::FilePath &fileName) const
+Snapshot::const_iterator Snapshot::find(const FilePath &filePath) const
 {
-    return _documents.find(fileName);
+    return _documents.find(filePath);
 }
 
-void Snapshot::remove(const Utils::FilePath &fileName)
+void Snapshot::remove(const FilePath &filePath)
 {
-    _documents.remove(fileName);
+    _documents.remove(filePath);
 }
 
-bool Snapshot::contains(const Utils::FilePath &fileName) const
+bool Snapshot::contains(const FilePath &filePath) const
 {
-    return _documents.contains(fileName);
+    return _documents.contains(filePath);
 }
 
 void Snapshot::insert(Document::Ptr doc)
 {
     if (doc) {
-        _documents.insert(Utils::FilePath::fromString(doc->fileName()), doc);
+        _documents.insert(doc->filePath(), doc);
         m_deps.files.clear(); // Will trigger re-build when accessed.
     }
 }
@@ -717,11 +718,11 @@ static QList<Macro> macrosDefinedUntilLine(const QList<Macro> &macros, int line)
 }
 
 Document::Ptr Snapshot::preprocessedDocument(const QByteArray &source,
-                                             const Utils::FilePath &fileName,
+                                             const FilePath &filePath,
                                              int withDefinedMacrosFromDocumentUntilLine) const
 {
-    Document::Ptr newDoc = Document::create(fileName.toString());
-    if (Document::Ptr thisDocument = document(fileName)) {
+    Document::Ptr newDoc = Document::create(filePath);
+    if (Document::Ptr thisDocument = document(filePath)) {
         newDoc->_revision = thisDocument->_revision;
         newDoc->_editorRevision = thisDocument->_editorRevision;
         newDoc->_lastModified = thisDocument->_lastModified;
@@ -742,11 +743,11 @@ Document::Ptr Snapshot::preprocessedDocument(const QByteArray &source,
 }
 
 Document::Ptr Snapshot::documentFromSource(const QByteArray &preprocessedCode,
-                                           const QString &fileName) const
+                                           const FilePath &filePath) const
 {
-    Document::Ptr newDoc = Document::create(fileName);
+    Document::Ptr newDoc = Document::create(filePath);
 
-    if (Document::Ptr thisDocument = document(fileName)) {
+    if (Document::Ptr thisDocument = document(filePath)) {
         newDoc->_revision = thisDocument->_revision;
         newDoc->_editorRevision = thisDocument->_editorRevision;
         newDoc->_lastModified = thisDocument->_lastModified;
@@ -761,18 +762,18 @@ Document::Ptr Snapshot::documentFromSource(const QByteArray &preprocessedCode,
     return newDoc;
 }
 
-QSet<QString> Snapshot::allIncludesForDocument(const QString &fileName) const
+QSet<FilePath> Snapshot::allIncludesForDocument(const FilePath &filePath) const
 {
-    QSet<QString> result;
+    QSet<FilePath> result;
 
-    QStack<QString> files;
-    files.push(fileName);
+    QStack<FilePath> files;
+    files.push(filePath);
 
     while (!files.isEmpty()) {
-        QString file = files.pop();
+        FilePath file = files.pop();
         if (Document::Ptr doc = document(file)) {
-            const QStringList includedFiles = doc->includedFiles();
-            for (const QString &inc : includedFiles) {
+            const FilePaths includedFiles = doc->includedFiles();
+            for (const FilePath &inc : includedFiles) {
                 if (!result.contains(inc)) {
                     result.insert(inc);
                     files.push(inc);
@@ -784,24 +785,40 @@ QSet<QString> Snapshot::allIncludesForDocument(const QString &fileName) const
     return result;
 }
 
-QList<Snapshot::IncludeLocation> Snapshot::includeLocationsOfDocument(const QString &fileName) const
+QList<Snapshot::IncludeLocation> Snapshot::includeLocationsOfDocument(
+        const FilePath &fileNameOrPath) const
 {
+    const bool matchFullPath = fileNameOrPath.isAbsolutePath();
+    const auto isMatch = [&](const Document::Include &include) {
+        if (matchFullPath)
+            return include.resolvedFileName() == fileNameOrPath;
+        return include.resolvedFileName().fileName() == fileNameOrPath.fileName();
+    };
     QList<IncludeLocation> result;
     for (const_iterator cit = begin(), citEnd = end(); cit != citEnd; ++cit) {
         const Document::Ptr doc = cit.value();
         const QList<Document::Include> includeFiles = doc->resolvedIncludes();
+        bool foundMatch = false;
         for (const Document::Include &includeFile : includeFiles) {
-            if (includeFile.resolvedFileName() == fileName)
+            if (isMatch(includeFile)) {
+                foundMatch = true;
                 result.push_back({doc, includeFile.line()});
+            }
+        }
+        if (!matchFullPath && !foundMatch) {
+            for (const auto &includeFile : cit.value()->unresolvedIncludes()) {
+                if (includeFile.unresolvedFileName() == fileNameOrPath.path())
+                    result.push_back({doc, includeFile.line()});
+            }
         }
     }
     return result;
 }
 
-Utils::FilePaths Snapshot::filesDependingOn(const Utils::FilePath &fileName) const
+FilePaths Snapshot::filesDependingOn(const FilePath &filePath) const
 {
     updateDependencyTable();
-    return m_deps.filesDependingOn(fileName);
+    return m_deps.filesDependingOn(filePath);
 }
 
 void Snapshot::updateDependencyTable() const
@@ -821,9 +838,9 @@ bool Snapshot::operator==(const Snapshot &other) const
     return _documents == other._documents;
 }
 
-Document::Ptr Snapshot::document(const Utils::FilePath &fileName) const
+Document::Ptr Snapshot::document(const FilePath &filePath) const
 {
-    return _documents.value(fileName);
+    return _documents.value(filePath);
 }
 
 Snapshot Snapshot::simplified(Document::Ptr doc) const
@@ -832,9 +849,9 @@ Snapshot Snapshot::simplified(Document::Ptr doc) const
 
     if (doc) {
         snapshot.insert(doc);
-        const QSet<QString> fileNames = allIncludesForDocument(doc->fileName());
-        for (const QString &fileName : fileNames)
-            if (Document::Ptr inc = document(fileName))
+        const QSet<FilePath> filePaths = allIncludesForDocument(doc->filePath());
+        for (const FilePath &filePath : filePaths)
+            if (Document::Ptr inc = document(filePath))
                 snapshot.insert(inc);
     }
 
