@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "LookupContext.h"
 
@@ -21,7 +21,9 @@
 #include <QVarLengthArray>
 #include <QDebug>
 
-using namespace CPlusPlus;
+using namespace Utils;
+
+namespace CPlusPlus {
 
 static const bool debug = qEnvironmentVariableIsSet("QTC_LOOKUPCONTEXT_DEBUG");
 
@@ -86,8 +88,6 @@ static bool isNestedInstantiationEnclosingTemplate(
     return true;
 }
 
-namespace CPlusPlus {
-
 static inline bool compareName(const Name *name, const Name *other)
 {
     if (name == other)
@@ -117,9 +117,6 @@ bool compareFullyQualifiedName(const QList<const Name *> &path, const QList<cons
     return true;
 }
 
-}
-
-namespace CPlusPlus {
 namespace Internal {
 
 bool operator==(const FullyQualifiedName &left, const FullyQualifiedName &right)
@@ -140,7 +137,7 @@ size_t qHash(const FullyQualifiedName &fullyQualifiedName)
     }
     return h;
 }
-}
+
 }
 
 /////////////////////////////////////////////////////////////////////
@@ -152,7 +149,7 @@ LookupContext::LookupContext()
 
 LookupContext::LookupContext(Document::Ptr thisDocument,
                              const Snapshot &snapshot)
-    : _expressionDocument(Document::create(QLatin1String("<LookupContext>")))
+    : _expressionDocument(Document::create(FilePath::fromPathPart(u"<LookupContext>")))
     , _thisDocument(thisDocument)
     , _snapshot(snapshot)
     , _bindings(new CreateBindings(thisDocument, snapshot))
@@ -192,6 +189,8 @@ LookupContext &LookupContext::operator=(const LookupContext &other)
 
 QList<const Name *> LookupContext::fullyQualifiedName(Symbol *symbol, InlineNamespacePolicy policy)
 {
+    if (symbol->asTypenameArgument())
+        return {symbol->name()};
     QList<const Name *> qualifiedName = path(symbol->enclosingScope(), policy);
     addNames(symbol->name(), &qualifiedName, /*add all names*/ true);
     return qualifiedName;
@@ -232,11 +231,11 @@ static bool isInlineNamespace(ClassOrNamespace *con, const Name *name)
 const Name *LookupContext::minimalName(Symbol *symbol, ClassOrNamespace *target, Control *control)
 {
     const Name *n = nullptr;
+    std::optional<QList<const Name *>> minimal;
     QList<const Name *> names = LookupContext::fullyQualifiedName(symbol);
-    ClassOrNamespace *current = target;
 
     const auto getNameFromItems = [symbol, target, control](const QList<LookupItem> &items,
-            const QList<const Name *> &names) -> const Name * {
+            const QList<const Name *> &names) -> std::optional<QList<const Name *>> {
         for (const LookupItem &item : items) {
             if (!symbol->asUsingDeclaration() && !symbolIdentical(item.declaration(), symbol))
                 continue;
@@ -249,41 +248,54 @@ const Name *LookupContext::minimalName(Symbol *symbol, ClassOrNamespace *target,
                     minimal.removeAt(i);
             }
 
-            return control->toName(minimal);
+            return minimal;
         }
-
-        return nullptr;
+        return {};
     };
 
-    for (int i = names.size() - 1; i >= 0; --i) {
-        if (! n)
-            n = names.at(i);
-        else
-            n = control->qualifiedNameId(names.at(i), n);
+    do {
+        ClassOrNamespace *current = target;
+        n = nullptr;
 
-        // once we're qualified enough to get the same symbol, break
-        if (target) {
-            const Name * const minimal = getNameFromItems(target->lookup(n), names.mid(i));
-            if (minimal)
-                return minimal;
-        }
-        if (current) {
-            const ClassOrNamespace * const nested = current->getNested(names.last());
-            if (nested) {
-                const QList<const Name *> nameList
-                        = names.mid(0, names.size() - i - 1) << names.last();
-                const QList<ClassOrNamespace *> usings = nested->usings();
-                for (ClassOrNamespace * const u : usings) {
-                    const Name * const minimal = getNameFromItems(u->lookup(symbol->name()),
-                                                                  nameList);
-                    if (minimal)
-                        return minimal;
+        for (int i = names.size() - 1; i >= 0; --i) {
+            if (! n)
+                n = names.at(i);
+            else
+                n = control->qualifiedNameId(names.at(i), n);
+
+            if (target) {
+                const auto candidate = getNameFromItems(target->lookup(n), names.mid(i));
+                if (candidate && (!minimal || minimal->size() > candidate->size())) {
+                    minimal = candidate;
+                    if (minimal && minimal->size() == 1)
+                        return control->toName(*minimal);
                 }
             }
-            current = current->getNested(names.at(names.size() - i - 1));
-        }
-    }
 
+            if (current) {
+                const ClassOrNamespace * const nested = current->getNested(names.last());
+                if (nested) {
+                    const QList<const Name *> nameList
+                            = names.mid(0, names.size() - i - 1) << names.last();
+                    const QList<ClassOrNamespace *> usings = nested->usings();
+                    for (ClassOrNamespace * const u : usings) {
+                        const auto candidate = getNameFromItems(u->lookup(symbol->name()), nameList);
+                        if (candidate && (!minimal || minimal->size() > candidate->size())) {
+                            minimal = candidate;
+                            if (minimal && minimal->size() == 1)
+                                return control->toName(*minimal);
+                        }
+                    }
+                }
+                current = current->getNested(names.at(names.size() - i - 1));
+            }
+        }
+        if (target)
+            target = target->parent();
+    } while (target);
+
+    if (minimal)
+        return control->toName(*minimal);
     return n;
 }
 
@@ -342,8 +354,8 @@ Document::Ptr LookupContext::expressionDocument() const
 Document::Ptr LookupContext::thisDocument() const
 { return _thisDocument; }
 
-Document::Ptr LookupContext::document(const QString &fileName) const
-{ return _snapshot.document(fileName); }
+Document::Ptr LookupContext::document(const FilePath &filePath) const
+{ return _snapshot.document(filePath); }
 
 Snapshot LookupContext::snapshot() const
 { return _snapshot; }
@@ -2059,3 +2071,4 @@ Symbol *CreateBindings::instantiateTemplateFunction(const Name *instantiationNam
     return cloner.symbol(specialization, &subst);
 }
 
+} // CPlusPlus
