@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "TypeOfExpression.h"
 
@@ -13,7 +13,9 @@
 
 #include <QSet>
 
-using namespace CPlusPlus;
+using namespace Utils;
+
+namespace CPlusPlus {
 
 TypeOfExpression::TypeOfExpression():
     m_ast(nullptr),
@@ -132,8 +134,8 @@ ExpressionAST *TypeOfExpression::expressionAST() const
 void TypeOfExpression::processEnvironment(Document::Ptr doc, Environment *env,
                                           QSet<QString> *processed) const
 {
-    if (doc && ! processed->contains(doc->fileName())) {
-        processed->insert(doc->fileName());
+    if (doc && ! processed->contains(doc->filePath().path())) {
+        processed->insert(doc->filePath().path());
 
         const QList<Document::Include> includes = doc->resolvedIncludes();
         for (const Document::Include &incl : includes)
@@ -158,11 +160,9 @@ QByteArray TypeOfExpression::preprocessedExpression(const QByteArray &utf8code)
     }
 
     Preprocessor preproc(nullptr, m_environment.data());
-    return preproc.run(QLatin1String("<expression>"), utf8code);
+    return preproc.run(Utils::FilePath::fromParts({}, {}, u"<expression>"), utf8code);
 }
 
-namespace CPlusPlus {
-
 ExpressionAST *extractExpressionAST(Document::Ptr doc)
 {
     if (! doc->translationUnit()->ast())
@@ -174,10 +174,10 @@ ExpressionAST *extractExpressionAST(Document::Ptr doc)
 Document::Ptr documentForExpression(const QByteArray &utf8code)
 {
     // create the expression's AST.
-    Document::Ptr doc = Document::create(QLatin1String("<completion>"));
+    Document::Ptr doc = Document::create(FilePath::fromPathPart(u"<completion>"));
     doc->setUtf8Source(utf8code);
     doc->parse(Document::ParseExpression);
     return doc;
 }
 
-} // namespace CPlusPlus
+} // CPlusPlus
