@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "terminalprocess_p.h"
 
@@ -31,7 +9,7 @@
 #include "qtcassert.h"
 #include "qtcprocess.h"
 #include "terminalcommand.h"
-#include "winutils.h"
+#include "utilstr.h"
 
 #include <QCoreApplication>
 #include <QLocalServer>
@@ -44,17 +22,19 @@
 
 #ifdef Q_OS_WIN
 
-#  include <windows.h>
-#  include <stdlib.h>
-#  include <cstring>
+#include "winutils.h"
+
+#include <cstring>
+#include <stdlib.h>
+#include <windows.h>
 
 #else
 
-#  include <sys/stat.h>
-#  include <sys/types.h>
-#  include <errno.h>
-#  include <string.h>
-#  include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <errno.h>
+#include <string.h>
+#include <unistd.h>
 
 #endif
 
@@ -79,44 +59,44 @@ static QString modeOption(TerminalMode m)
 
 static QString msgCommChannelFailed(const QString &error)
 {
-    return QtcProcess::tr("Cannot set up communication channel: %1").arg(error);
+    return Tr::tr("Cannot set up communication channel: %1").arg(error);
 }
 
 static QString msgPromptToClose()
 {
     // Shown in a terminal which might have a different character set on Windows.
-    return QtcProcess::tr("Press <RETURN> to close this window...");
+    return Tr::tr("Press <RETURN> to close this window...");
 }
 
 static QString msgCannotCreateTempFile(const QString &why)
 {
-    return QtcProcess::tr("Cannot create temporary file: %1").arg(why);
+    return Tr::tr("Cannot create temporary file: %1").arg(why);
 }
 
 static QString msgCannotWriteTempFile()
 {
-    return QtcProcess::tr("Cannot write temporary file. Disk full?");
+    return Tr::tr("Cannot write temporary file. Disk full?");
 }
 
 static QString msgCannotCreateTempDir(const QString & dir, const QString &why)
 {
-    return QtcProcess::tr("Cannot create temporary directory \"%1\": %2").arg(dir, why);
+    return Tr::tr("Cannot create temporary directory \"%1\": %2").arg(dir, why);
 }
 
 static QString msgUnexpectedOutput(const QByteArray &what)
 {
-    return QtcProcess::tr("Unexpected output from helper program (%1).")
+    return Tr::tr("Unexpected output from helper program (%1).")
         .arg(QString::fromLatin1(what));
 }
 
 static QString msgCannotChangeToWorkDir(const FilePath &dir, const QString &why)
 {
-    return QtcProcess::tr("Cannot change to working directory \"%1\": %2").arg(dir.toString(), why);
+    return Tr::tr("Cannot change to working directory \"%1\": %2").arg(dir.toString(), why);
 }
 
 static QString msgCannotExecute(const QString & p, const QString &why)
 {
-    return QtcProcess::tr("Cannot execute \"%1\": %2").arg(p, why);
+    return Tr::tr("Cannot execute \"%1\": %2").arg(p, why);
 }
 
 class TerminalProcessPrivate
@@ -204,15 +184,15 @@ void TerminalImpl::start()
             QStringList envStrings = env;
             // add PATH if necessary (for DLL loading)
             if (envStrings.filter(QRegularExpression("^PATH=.*", QRegularExpression::CaseInsensitiveOption)).isEmpty()) {
-                QByteArray path = qgetenv("PATH");
+                const QString path = qtcEnvironmentVariable("PATH");
                 if (!path.isEmpty())
-                    envStrings.prepend(QString::fromLatin1("PATH=%1").arg(QString::fromLocal8Bit(path)));
+                    envStrings.prepend(QString::fromLatin1("PATH=%1").arg(path));
             }
             // add systemroot if needed
             if (envStrings.filter(QRegularExpression("^SystemRoot=.*", QRegularExpression::CaseInsensitiveOption)).isEmpty()) {
-                QByteArray systemRoot = qgetenv("SystemRoot");
+                const QString systemRoot = qtcEnvironmentVariable("SystemRoot");
                 if (!systemRoot.isEmpty())
-                    envStrings.prepend(QString::fromLatin1("SystemRoot=%1").arg(QString::fromLocal8Bit(systemRoot)));
+                    envStrings.prepend(QString::fromLatin1("SystemRoot=%1").arg(systemRoot));
             }
             return envStrings;
         }();
@@ -311,7 +291,7 @@ void TerminalImpl::start()
     if (!success) {
         delete d->m_pid;
         d->m_pid = nullptr;
-        const QString msg = QtcProcess::tr("The process \"%1\" could not be started: %2")
+        const QString msg = Tr::tr("The process \"%1\" could not be started: %2")
                                 .arg(cmdLine, winErrorMessage(GetLastError()));
         cleanupAfterStartFailure(msg);
         return;
@@ -336,17 +316,17 @@ void TerminalImpl::start()
         pcmd = m_setup.m_commandLine.executable().toString();
     } else {
         if (perr != ProcessArgs::FoundMeta) {
-            emitError(QProcess::FailedToStart, QtcProcess::tr("Quoting error in command."));
+            emitError(QProcess::FailedToStart, Tr::tr("Quoting error in command."));
             return;
         }
         if (m_setup.m_terminalMode == TerminalMode::Debug) {
             // FIXME: QTCREATORBUG-2809
             emitError(QProcess::FailedToStart,
-                      QtcProcess::tr("Debugging complex shell commands in a terminal"
-                                     " is currently not supported."));
+                      Tr::tr("Debugging complex shell commands in a terminal"
+                             " is currently not supported."));
             return;
         }
-        pcmd = qEnvironmentVariable("SHELL", "/bin/sh");
+        pcmd = qtcEnvironmentVariable("SHELL", "/bin/sh");
         pargs = ProcessArgs::createUnixArgs(
                         {"-c", (ProcessArgs::quoteArg(m_setup.m_commandLine.executable().toString())
                          + ' ' + m_setup.m_commandLine.arguments())});
@@ -362,8 +342,8 @@ void TerminalImpl::start()
     if (qerr != ProcessArgs::SplitOk) {
         emitError(QProcess::FailedToStart,
                   qerr == ProcessArgs::BadQuoting
-                      ? QtcProcess::tr("Quoting error in terminal command.")
-                      : QtcProcess::tr("Terminal command may not be a shell command."));
+                      ? Tr::tr("Quoting error in terminal command.")
+                      : Tr::tr("Terminal command may not be a shell command."));
         return;
     }
 
@@ -412,15 +392,15 @@ void TerminalImpl::start()
         allArgs = QStringList { ProcessArgs::joinArgs(allArgs) };
 
     d->m_process.setEnvironment(m_setup.m_environment);
-    d->m_process.setCommand({FilePath::fromString(terminal.command), allArgs});
+    d->m_process.setCommand({terminal.command, allArgs});
     d->m_process.setProcessImpl(m_setup.m_processImpl);
     d->m_process.setReaperTimeout(m_setup.m_reaperTimeout);
+
     d->m_process.start();
     if (!d->m_process.waitForStarted()) {
-        const QString msg
-            = QtcProcess::tr("Cannot start the terminal emulator \"%1\", change the setting in the "
-                             "Environment options.")
-                  .arg(terminal.command);
+        const QString msg = Tr::tr("Cannot start the terminal emulator \"%1\", change the "
+                                           "setting in the Environment preferences. (%2)")
+                                .arg(terminal.command.toUserOutput(), d->m_process.errorString());
         cleanupAfterStartFailure(msg);
         return;
     }
@@ -445,7 +425,9 @@ void TerminalImpl::sendControlSignal(ControlSignal controlSignal)
     switch (controlSignal) {
     case ControlSignal::Terminate:
     case ControlSignal::Kill:
-        stopProcess();
+        killProcess();
+        if (HostOsInfo::isWindowsHost())
+            killStub();
         break;
     case ControlSignal::Interrupt:
         sendCommand('i');
@@ -453,6 +435,9 @@ void TerminalImpl::sendControlSignal(ControlSignal controlSignal)
     case ControlSignal::KickOff:
         sendCommand('c');
         break;
+    case ControlSignal::CloseWriteChannel:
+        QTC_CHECK(false);
+        break;
     }
 }
 
@@ -490,13 +475,13 @@ void TerminalImpl::killStub()
     TerminateProcess(d->m_pid->hProcess, (unsigned)-1);
     WaitForSingleObject(d->m_pid->hProcess, INFINITE);
     cleanupStub();
+    emitFinished(-1, QProcess::CrashExit);
 #else
     sendCommand('s');
     stubServerShutdown();
+    d->m_process.stop();
     d->m_process.waitForFinished();
 #endif
-
-    emitFinished(-1, QProcess::CrashExit);
 }
 
 void TerminalImpl::stopProcess()
@@ -541,13 +526,13 @@ QString TerminalImpl::stubServerListen()
         if (errno != EEXIST)
             return msgCannotCreateTempDir(stubFifoDir, QString::fromLocal8Bit(strerror(errno)));
     }
-    const QString stubServer  = stubFifoDir + QLatin1String("/stub-socket");
+    const QString stubServer = stubFifoDir + QLatin1String("/stub-socket");
     if (!d->m_stubServer.listen(stubServer)) {
         ::rmdir(d->m_stubServerDir.constData());
-        return QtcProcess::tr("Cannot create socket \"%1\": %2")
+        return Tr::tr("Cannot create socket \"%1\": %2")
             .arg(stubServer, d->m_stubServer.errorString());
     }
-    return QString();
+    return {};
 #endif
 }
 
@@ -617,7 +602,7 @@ void TerminalImpl::readStubOutput()
                     FALSE, d->m_processId);
             if (d->m_hInferior == NULL) {
                 emitError(QProcess::FailedToStart,
-                          QtcProcess::tr("Cannot obtain a handle to the inferior: %1")
+                          Tr::tr("Cannot obtain a handle to the inferior: %1")
                               .arg(winErrorMessage(GetLastError())));
                 // Uhm, and now what?
                 continue;
@@ -628,7 +613,7 @@ void TerminalImpl::readStubOutput()
 
                 if (!GetExitCodeProcess(d->m_hInferior, &chldStatus))
                     emitError(QProcess::UnknownError,
-                              QtcProcess::tr("Cannot obtain exit status from inferior: %1")
+                              Tr::tr("Cannot obtain exit status from inferior: %1")
                                   .arg(winErrorMessage(GetLastError())));
                 cleanupInferior();
                 emitFinished(chldStatus, QProcess::NormalExit);
