@@ -1,30 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 Hugues Delorme
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 Hugues Delorme
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "bazaareditor.h"
+
 #include "annotationhighlighter.h"
+#include "bazaartr.h"
 #include "constants.h"
 
 #include <utils/qtcassert.h>
@@ -34,15 +14,14 @@
 
 #define BZR_CHANGE_PATTERN "[0-9]+"
 
-using namespace Bazaar::Internal;
-using namespace Bazaar;
+namespace Bazaar::Internal {
 
 BazaarEditorWidget::BazaarEditorWidget() :
     m_changesetId(QLatin1String(Constants::CHANGESET_ID)),
     m_exactChangesetId(QLatin1String(Constants::CHANGESET_ID_EXACT))
 {
-    setAnnotateRevisionTextFormat(tr("&Annotate %1"));
-    setAnnotatePreviousRevisionTextFormat(tr("Annotate &parent revision %1"));
+    setAnnotateRevisionTextFormat(Tr::tr("&Annotate %1"));
+    setAnnotatePreviousRevisionTextFormat(Tr::tr("Annotate &parent revision %1"));
     // Diff format:
     // === <change> <file|dir> 'mainwindow.cpp'
     setDiffFilePattern("^=== [a-z]+ [a-z]+ '(.+)'\\s*");
@@ -84,3 +63,5 @@ VcsBase::BaseAnnotationHighlighter *BazaarEditorWidget::createAnnotationHighligh
 {
     return new BazaarAnnotationHighlighter(changes);
 }
+
+} // Bazaar::Internal
