@@ -1,39 +1,19 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "clangtoolsdiagnosticmodel.h"
 
 #include "clangtoolsdiagnosticview.h"
 #include "clangtoolsprojectsettings.h"
+#include "clangtoolstr.h"
 #include "clangtoolsutils.h"
 #include "diagnosticmark.h"
 
-#include <coreplugin/fileiconprovider.h>
 #include <projectexplorer/project.h>
 #include <projectexplorer/session.h>
 #include <texteditor/textmark.h>
+
+#include <utils/fsengine/fileiconprovider.h>
 #include <utils/qtcassert.h>
 #include <utils/utilsicons.h>
 
@@ -47,7 +27,7 @@ static Q_LOGGING_CATEGORY(LOG, "qtc.clangtools.model", QtWarningMsg)
 namespace ClangTools {
 namespace Internal {
 
-FilePathItem::FilePathItem(const QString &filePath)
+FilePathItem::FilePathItem(const Utils::FilePath &filePath)
     : m_filePath(filePath)
 {}
 
@@ -56,11 +36,11 @@ QVariant FilePathItem::data(int column, int role) const
     if (column == DiagnosticView::DiagnosticColumn) {
         switch (role) {
         case Qt::DisplayRole:
-            return m_filePath;
+            return m_filePath.toUserOutput();
         case Qt::DecorationRole:
-            return Core::FileIconProvider::icon(QFileInfo(m_filePath));
+            return Utils::FileIconProvider::icon(m_filePath);
         case Debugger::DetailedErrorView::FullTextRole:
-            return m_filePath;
+            return m_filePath.toUserOutput();
         default:
             return QVariant();
         }
@@ -119,12 +99,12 @@ void ClangToolsDiagnosticModel::addDiagnostics(const Diagnostics &diagnostics, b
         }
 
         // Create file path item if necessary
-        const QString filePath = d.location.filePath;
+        const Utils::FilePath &filePath = d.location.filePath;
         FilePathItem *&filePathItem = m_filePathToItem[filePath];
         if (!filePathItem) {
             filePathItem = new FilePathItem(filePath);
             rootItem()->appendChild(filePathItem);
-            addWatchedPath(d.location.filePath);
+            addWatchedPath(filePath.toString());
         }
 
         // Add to file path item
@@ -160,7 +140,7 @@ void ClangToolsDiagnosticModel::clear()
 
 void ClangToolsDiagnosticModel::updateItems(const DiagnosticItem *changedItem)
 {
-    for (auto item : stepsToItemsCache[changedItem->diagnostic().explainingSteps]) {
+    for (auto item : std::as_const(stepsToItemsCache[changedItem->diagnostic().explainingSteps])) {
         if (item != changedItem)
             item->setFixItStatus(changedItem->fixItStatus());
     }
@@ -184,7 +164,7 @@ void ClangToolsDiagnosticModel::clearAndSetupCache()
 void ClangToolsDiagnosticModel::onFileChanged(const QString &path)
 {
     forItemsAtLevel<2>([&](DiagnosticItem *item){
-        if (item->diagnostic().location.filePath == path)
+        if (item->diagnostic().location.filePath == Utils::FilePath::fromString(path))
             item->setFixItStatus(FixitStatus::Invalidated);
     });
     removeWatchedPath(path);
@@ -211,21 +191,19 @@ static QString createExplainingStepToolTipString(const ExplainingStep &step)
     QList<StringPair> lines;
 
     if (!step.message.isEmpty()) {
-        lines << qMakePair(
-            QCoreApplication::translate("ClangTools::ExplainingStep", "Message:"),
-                step.message.toHtmlEscaped());
+        lines.push_back({Tr::tr("Message:"),
+                         step.message.toHtmlEscaped()});
     }
 
-    lines << qMakePair(
-        QCoreApplication::translate("ClangTools::ExplainingStep", "Location:"),
-                createFullLocationString(step.location));
+    lines.push_back({Tr::tr("Location:"),
+                     createFullLocationString(step.location)});
 
     QString html = QLatin1String("<html>"
                    "<head>"
                    "<style>dt { font-weight:bold; } dd { font-family: monospace; }</style>\n"
                    "<body><dl>");
 
-    foreach (const StringPair &pair, lines) {
+    for (const StringPair &pair : std::as_const(lines)) {
         html += QLatin1String("<dt>");
         html += pair.first;
         html += QLatin1String("</dt><dd>");
@@ -238,7 +216,7 @@ static QString createExplainingStepToolTipString(const ExplainingStep &step)
 
 static QString createLocationString(const Debugger::DiagnosticLocation &location)
 {
-    const QString filePath = location.filePath;
+    const QString filePath = location.filePath.toUserOutput();
     const QString lineNumber = QString::number(location.line);
     const QString fileAndLine = filePath + QLatin1Char(':') + lineNumber;
     return QLatin1String("in ") + fileAndLine;
@@ -262,7 +240,7 @@ static QString createExplainingStepString(const ExplainingStep &explainingStep,
 
 static QString fullText(const Diagnostic &diagnostic)
 {
-    QString text = diagnostic.location.filePath + QLatin1Char(':');
+    QString text = diagnostic.location.filePath.toUserOutput() + QLatin1Char(':');
     text += lineColumnString(diagnostic.location) + QLatin1String(": ");
     if (!diagnostic.category.isEmpty())
         text += diagnostic.category + QLatin1String(": ");
@@ -273,7 +251,7 @@ static QString fullText(const Diagnostic &diagnostic)
 
     // Explaining steps.
     int explainingStepNumber = 1;
-    foreach (const ExplainingStep &explainingStep, diagnostic.explainingSteps) {
+    for (const ExplainingStep &explainingStep : std::as_const(diagnostic.explainingSteps)) {
         text += createExplainingStepString(explainingStep, explainingStepNumber++)
                 + QLatin1Char('\n');
     }
@@ -452,7 +430,9 @@ QVariant ExplainingStepItem::data(int column, int role) const
             return QVariant::fromValue(m_step.location);
         case Debugger::DetailedErrorView::FullTextRole: {
             return QString("%1:%2: %3")
-                .arg(m_step.location.filePath, lineColumnString(m_step.location), m_step.message);
+                .arg(m_step.location.filePath.toUserOutput(),
+                     lineColumnString(m_step.location),
+                     m_step.message);
         }
         case ClangToolsDiagnosticModel::TextRole:
             return m_step.message;
@@ -461,11 +441,12 @@ QVariant ExplainingStepItem::data(int column, int role) const
         case ClangToolsDiagnosticModel::DocumentationUrlRole:
             return parent()->data(column, role);
         case Qt::DisplayRole: {
-            const QString mainFilePath = static_cast<DiagnosticItem *>(parent())->diagnostic().location.filePath;
+            const Utils::FilePath mainFilePath
+                = static_cast<DiagnosticItem *>(parent())->diagnostic().location.filePath;
             const QString locationString
                 = m_step.location.filePath == mainFilePath
                       ? lineColumnString(m_step.location)
-                      : QString("%1:%2").arg(QFileInfo(m_step.location.filePath).fileName(),
+                      : QString("%1:%2").arg(m_step.location.filePath.fileName(),
                                              lineColumnString(m_step.location));
 
             if (m_step.isFixIt) {
@@ -509,7 +490,7 @@ DiagnosticFilterModel::DiagnosticFilterModel(QObject *parent)
                 if (!m_project && project->projectDirectory() == m_lastProjectDirectory)
                     setProject(project);
             });
-    connect(this, &QAbstractItemModel::modelReset, this, [this]() {
+    connect(this, &QAbstractItemModel::modelReset, this, [this] {
         reset();
         emit fixitCountersChanged(m_fixitsScheduled, m_fixitsScheduable);
     });
@@ -642,13 +623,12 @@ bool DiagnosticFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &s
         }
 
         // Explicitly suppressed?
-        foreach (const SuppressedDiagnostic &d, m_suppressedDiagnostics) {
+        for (const SuppressedDiagnostic &d : std::as_const(m_suppressedDiagnostics)) {
             if (d.description != diag.description)
                 continue;
-            QString filePath = d.filePath.toString();
-            QFileInfo fi(filePath);
-            if (fi.isRelative())
-                filePath = m_lastProjectDirectory.toString() + QLatin1Char('/') + filePath;
+            Utils::FilePath filePath = d.filePath;
+            if (d.filePath.toFileInfo().isRelative())
+                filePath = m_lastProjectDirectory.pathAppended(filePath.toString());
             if (filePath == diag.location.filePath) {
                 diagnosticItem->setTextMarkVisible(false);
                 return false;
