@@ -1,9 +1,10 @@
 // Copyright (C) 2018 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "cmaketoolsettingsaccessor.h"
 
 #include "cmakeprojectmanagertr.h"
+#include "cmakespecificsettings.h"
 #include "cmaketool.h"
 
 #include <coreplugin/icore.h>
@@ -66,18 +67,13 @@ static std::vector<std::unique_ptr<CMakeTool>> autoDetectCMakeTools()
         path.append("/opt/local/bin");    // macports
     }
 
-    const QStringList execs = env.appendExeExtensions(QLatin1String("cmake"));
-
     FilePaths suspects;
     for (const FilePath &base : std::as_const(path)) {
         if (base.isEmpty())
             continue;
-
-        for (const QString &exec : execs) {
-            const FilePath suspect = base.resolvePath(exec);
-            if (suspect.isExecutableFile())
-                suspects << suspect;
-        }
+        const FilePath suspect = base / "cmake";
+        if (std::optional<FilePath> foundExe = suspect.refersToExecutableFile(FilePath::WithAnySuffix))
+            suspects << *foundExe;
     }
 
     std::vector<std::unique_ptr<CMakeTool>> found;
@@ -190,9 +186,14 @@ void CMakeToolSettingsAccessor::saveCMakeTools(const QList<CMakeTool *> &cmakeTo
     data.insert(QLatin1String(CMAKE_TOOL_DEFAULT_KEY), defaultId.toSetting());
 
     int count = 0;
-    for (const CMakeTool *item : cmakeTools) {
+    for (CMakeTool *item : cmakeTools) {
         Utils::FilePath fi = item->cmakeExecutable();
 
+        // Gobal Autorun value will be set for all tools
+        // TODO: Remove in Qt Creator 13
+        const auto settings = CMakeSpecificSettings::instance();
+        item->setAutorun(settings->autorunCMake.value());
+
         if (fi.needsDevice() || fi.isExecutableFile()) { // be graceful for device related stuff
             QVariantMap tmp = item->toMap();
             if (tmp.isEmpty())
