@@ -1,35 +1,16 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Copyright (C) 2016 Falko Arps
-** Copyright (C) 2016 Sven Klein
-** Copyright (C) 2016 Giuliano Schneider
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// Copyright (C) 2016 Falko Arps
+// Copyright (C) 2016 Sven Klein
+// Copyright (C) 2016 Giuliano Schneider
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "ioptionspage.h"
 
-#include <utils/stringutils.h>
+#include <coreplugin/icore.h>
+
+#include <utils/aspects.h>
 #include <utils/qtcassert.h>
+#include <utils/stringutils.h>
 
 #include <QCheckBox>
 #include <QGroupBox>
@@ -40,6 +21,8 @@
 
 using namespace Utils;
 
+namespace Core {
+
 /*!
     \class Core::IOptionsPageProvider
     \inmodule QtCreator
@@ -94,7 +77,7 @@ using namespace Utils;
     Returns the category icon of the options page. This icon is displayed in the list on the left
     side of the \uicontrol Options dialog.
 */
-QIcon Core::IOptionsPage::categoryIcon() const
+QIcon IOptionsPage::categoryIcon() const
 {
     return m_categoryIcon.icon();
 }
@@ -103,11 +86,39 @@ QIcon Core::IOptionsPage::categoryIcon() const
     Sets the \a widgetCreator callback to create page widgets on demand. The
     widget will be destroyed on finish().
  */
-void Core::IOptionsPage::setWidgetCreator(const WidgetCreator &widgetCreator)
+void IOptionsPage::setWidgetCreator(const WidgetCreator &widgetCreator)
 {
     m_widgetCreator = widgetCreator;
 }
 
+/*!
+    \fn QStringList Core::IOptionsPage::keywords() const
+
+    Returns a list of ui strings that are used inside the widget.
+*/
+
+QStringList IOptionsPage::keywords() const
+{
+    if (!m_keywordsInitialized) {
+        auto that = const_cast<IOptionsPage *>(this);
+        QWidget *widget = that->widget();
+        if (!widget)
+            return {};
+        // find common subwidgets
+        for (const QLabel *label : widget->findChildren<QLabel *>())
+            m_keywords << Utils::stripAccelerator(label->text());
+        for (const QCheckBox *checkbox : widget->findChildren<QCheckBox *>())
+            m_keywords << Utils::stripAccelerator(checkbox->text());
+        for (const QPushButton *pushButton : widget->findChildren<QPushButton *>())
+            m_keywords << Utils::stripAccelerator(pushButton->text());
+        for (const QGroupBox *groupBox : widget->findChildren<QGroupBox *>())
+            m_keywords << Utils::stripAccelerator(groupBox->title());
+
+        m_keywordsInitialized = true;
+    }
+    return m_keywords;
+}
+
 /*!
     Returns the widget to show in the \uicontrol Options dialog. You should create a widget lazily here,
     and delete it again in the finish() method. This method can be called multiple times, so you
@@ -119,11 +130,18 @@ void Core::IOptionsPage::setWidgetCreator(const WidgetCreator &widgetCreator)
     Either override this function in a derived class, or set a widget creator.
 */
 
-QWidget *Core::IOptionsPage::widget()
+QWidget *IOptionsPage::widget()
 {
-    QTC_ASSERT(m_widgetCreator, return nullptr);
-    if (!m_widget)
-        m_widget = m_widgetCreator();
+    if (!m_widget) {
+        if (m_widgetCreator) {
+            m_widget = m_widgetCreator();
+        } else if (m_layouter) {
+            m_widget = new QWidget;
+            m_layouter(m_widget);
+        } else {
+            QTC_CHECK(false);
+        }
+    }
     return m_widget;
 }
 
@@ -136,11 +154,16 @@ QWidget *Core::IOptionsPage::widget()
     \sa setWidgetCreator()
 */
 
-void Core::IOptionsPage::apply()
+void IOptionsPage::apply()
 {
-    QTC_ASSERT(m_widgetCreator, return);
-    if (m_widget)
-        m_widget->apply();
+    if (auto widget = qobject_cast<IOptionsPageWidget *>(m_widget)) {
+        widget->apply();
+    } else if (m_settings) {
+        if (m_settings->isDirty()) {
+            m_settings->apply();
+            m_settings->writeSettings(ICore::settings());
+         }
+    }
 }
 
 /*!
@@ -152,24 +175,35 @@ void Core::IOptionsPage::apply()
     \sa setWidgetCreator()
 */
 
-void Core::IOptionsPage::finish()
+void IOptionsPage::finish()
 {
-    QTC_ASSERT(m_widgetCreator, return);
-    if (m_widget) {
-        m_widget->finish();
-        delete m_widget;
-    }
+    if (auto widget = qobject_cast<IOptionsPageWidget *>(m_widget))
+        widget->finish();
+    else if (m_settings)
+        m_settings->finish();
+
+    delete m_widget;
 }
 
 /*!
     Sets \a categoryIconPath as the path to the category icon of the options
     page.
 */
-void Core::IOptionsPage::setCategoryIconPath(const QString &categoryIconPath)
+void IOptionsPage::setCategoryIconPath(const FilePath &categoryIconPath)
 {
     m_categoryIcon = Icon({{categoryIconPath, Theme::PanelTextColorDark}}, Icon::Tint);
 }
 
+void IOptionsPage::setSettings(AspectContainer *settings)
+{
+    m_settings = settings;
+}
+
+void IOptionsPage::setLayouter(const std::function<void(QWidget *w)> &layouter)
+{
+    m_layouter = layouter;
+}
+
 /*!
     \fn void Core::IOptionsPage::setId(Utils::Id id)
 
@@ -200,13 +234,13 @@ void Core::IOptionsPage::setCategoryIconPath(const QString &categoryIconPath)
     Sets \a categoryIcon as the category icon of the options page.
 */
 
-static QList<Core::IOptionsPage *> g_optionsPages;
+static QList<IOptionsPage *> g_optionsPages;
 
 /*!
     Constructs an options page with the given \a parent and registers it
     at the global options page pool if \a registerGlobally is \c true.
 */
-Core::IOptionsPage::IOptionsPage(QObject *parent, bool registerGlobally)
+IOptionsPage::IOptionsPage(QObject *parent, bool registerGlobally)
     : QObject(parent)
 {
     if (registerGlobally)
@@ -216,7 +250,7 @@ Core::IOptionsPage::IOptionsPage(QObject *parent, bool registerGlobally)
 /*!
     \internal
  */
-Core::IOptionsPage::~IOptionsPage()
+IOptionsPage::~IOptionsPage()
 {
     g_optionsPages.removeOne(this);
 }
@@ -224,7 +258,7 @@ Core::IOptionsPage::~IOptionsPage()
 /*!
     Returns a list of all options pages.
  */
-const QList<Core::IOptionsPage *> Core::IOptionsPage::allOptionsPages()
+const QList<IOptionsPage *> IOptionsPage::allOptionsPages()
 {
     return g_optionsPages;
 }
@@ -234,50 +268,35 @@ const QList<Core::IOptionsPage *> Core::IOptionsPage::allOptionsPages()
     page. This defaults to take the widget and then looks for all child labels, check boxes, push
     buttons, and group boxes. Should return \c true when a match is found.
 */
-bool Core::IOptionsPage::matches(const QRegularExpression &regexp) const
+bool IOptionsPage::matches(const QRegularExpression &regexp) const
 {
-    if (!m_keywordsInitialized) {
-        auto that = const_cast<IOptionsPage *>(this);
-        QWidget *widget = that->widget();
-        if (!widget)
-            return false;
-        // find common subwidgets
-        foreach (const QLabel *label, widget->findChildren<QLabel *>())
-            m_keywords << Utils::stripAccelerator(label->text());
-        foreach (const QCheckBox *checkbox, widget->findChildren<QCheckBox *>())
-            m_keywords << Utils::stripAccelerator(checkbox->text());
-        foreach (const QPushButton *pushButton, widget->findChildren<QPushButton *>())
-            m_keywords << Utils::stripAccelerator(pushButton->text());
-        foreach (const QGroupBox *groupBox, widget->findChildren<QGroupBox *>())
-            m_keywords << Utils::stripAccelerator(groupBox->title());
-
-        m_keywordsInitialized = true;
-    }
-    foreach (const QString &keyword, m_keywords)
+    for (const QString &keyword : keywords())
         if (keyword.contains(regexp))
             return true;
     return false;
 }
 
-static QList<Core::IOptionsPageProvider *> g_optionsPagesProviders;
+static QList<IOptionsPageProvider *> g_optionsPagesProviders;
 
-Core::IOptionsPageProvider::IOptionsPageProvider(QObject *parent)
+IOptionsPageProvider::IOptionsPageProvider(QObject *parent)
     : QObject(parent)
 {
     g_optionsPagesProviders.append(this);
 }
 
-Core::IOptionsPageProvider::~IOptionsPageProvider()
+IOptionsPageProvider::~IOptionsPageProvider()
 {
     g_optionsPagesProviders.removeOne(this);
 }
 
-const QList<Core::IOptionsPageProvider *> Core::IOptionsPageProvider::allOptionsPagesProviders()
+const QList<IOptionsPageProvider *> IOptionsPageProvider::allOptionsPagesProviders()
 {
     return g_optionsPagesProviders;
 }
 
-QIcon Core::IOptionsPageProvider::categoryIcon() const
+QIcon IOptionsPageProvider::categoryIcon() const
 {
     return m_categoryIcon.icon();
 }
+
+} // Core
