@@ -1,40 +1,19 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "editortoolbar.h"
 
-#include <coreplugin/actionmanager/actionmanager.h>
-#include <coreplugin/actionmanager/command.h>
-#include <coreplugin/editormanager/documentmodel.h>
-#include <coreplugin/editormanager/editormanager.h>
-#include <coreplugin/editormanager/editormanager_p.h>
-#include <coreplugin/editormanager/ieditor.h>
-#include <coreplugin/fileiconprovider.h>
-#include <coreplugin/icore.h>
+#include "actionmanager/actionmanager.h"
+#include "actionmanager/command.h"
+#include "coreplugintr.h"
+#include "editormanager/documentmodel.h"
+#include "editormanager/editormanager.h"
+#include "editormanager/editormanager_p.h"
+#include "editormanager/ieditor.h"
+#include "icore.h"
 
-#include <utils/fileutils.h>
+#include <utils/filepath.h>
+#include <utils/fsengine/fileiconprovider.h>
 #include <utils/hostosinfo.h>
 #include <utils/qtcassert.h>
 #include <utils/utilsicons.h>
@@ -93,19 +72,19 @@ EditorToolBarPrivate::EditorToolBarPrivate(QWidget *parent, EditorToolBar *q) :
     m_closeEditorButton(new QToolButton(q)),
     m_lockButton(new QToolButton(q)),
     m_dragHandle(new QToolButton(q)),
-    m_dragHandleMenu(0),
-    m_goBackAction(new QAction(Utils::Icons::PREV_TOOLBAR.icon(), EditorManager::tr("Go Back"), parent)),
-    m_goForwardAction(new QAction(Utils::Icons::NEXT_TOOLBAR.icon(), EditorManager::tr("Go Forward"), parent)),
+    m_dragHandleMenu(nullptr),
+    m_goBackAction(new QAction(Utils::Icons::PREV_TOOLBAR.icon(), Tr::tr("Go Back"), parent)),
+    m_goForwardAction(new QAction(Utils::Icons::NEXT_TOOLBAR.icon(), Tr::tr("Go Forward"), parent)),
     m_backButton(new QToolButton(q)),
     m_forwardButton(new QToolButton(q)),
     m_splitButton(new QToolButton(q)),
     m_horizontalSplitAction(new QAction(Utils::Icons::SPLIT_HORIZONTAL.icon(),
-                                        EditorManager::tr("Split"), parent)),
+                                        Tr::tr("Split"), parent)),
     m_verticalSplitAction(new QAction(Utils::Icons::SPLIT_VERTICAL.icon(),
-                                      EditorManager::tr("Split Side by Side"), parent)),
-    m_splitNewWindowAction(new QAction(EditorManager::tr("Open in New Window"), parent)),
+                                      Tr::tr("Split Side by Side"), parent)),
+    m_splitNewWindowAction(new QAction(Tr::tr("Open in New Window"), parent)),
     m_closeSplitButton(new QToolButton(q)),
-    m_activeToolBar(0),
+    m_activeToolBar(nullptr),
     m_toolBarPlaceholder(new QWidget(q)),
     m_defaultToolBar(new QWidget(q)),
     m_isStandalone(false)
@@ -118,8 +97,8 @@ EditorToolBarPrivate::EditorToolBarPrivate(QWidget *parent, EditorToolBar *q) :
 EditorToolBar::EditorToolBar(QWidget *parent) :
         Utils::StyledBar(parent), d(new EditorToolBarPrivate(parent, this))
 {
-    QHBoxLayout *toolBarLayout = new QHBoxLayout(this);
-    toolBarLayout->setMargin(0);
+    auto toolBarLayout = new QHBoxLayout(this);
+    toolBarLayout->setContentsMargins(0, 0, 0, 0);
     toolBarLayout->setSpacing(0);
     toolBarLayout->addWidget(d->m_defaultToolBar);
     d->m_toolBarPlaceholder->setLayout(toolBarLayout);
@@ -128,11 +107,10 @@ EditorToolBar::EditorToolBar(QWidget *parent) :
     d->m_defaultToolBar->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     d->m_activeToolBar = d->m_defaultToolBar;
 
-    d->m_lockButton->setAutoRaise(true);
     d->m_lockButton->setEnabled(false);
 
     d->m_dragHandle->setProperty("noArrow", true);
-    d->m_dragHandle->setToolTip(tr("Drag to drag documents between splits"));
+    d->m_dragHandle->setToolTip(Tr::tr("Drag to drag documents between splits"));
     d->m_dragHandle->installEventFilter(this);
     d->m_dragHandleMenu = new QMenu(d->m_dragHandle);
     d->m_dragHandle->setMenu(d->m_dragHandleMenu);
@@ -142,6 +120,7 @@ EditorToolBar::EditorToolBar(QWidget *parent) :
 
     d->m_editorList->setProperty("hideicon", true);
     d->m_editorList->setProperty("notelideasterisk", true);
+    d->m_editorList->setProperty("elidemode", Qt::ElideMiddle);
     d->m_editorList->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     d->m_editorList->setMinimumContentsLength(20);
     d->m_editorList->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
@@ -149,7 +128,6 @@ EditorToolBar::EditorToolBar(QWidget *parent) :
     d->m_editorList->setMaxVisibleItems(40);
     d->m_editorList->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    d->m_closeEditorButton->setAutoRaise(true);
     d->m_closeEditorButton->setIcon(Utils::Icons::CLOSE_TOOLBAR.icon());
     d->m_closeEditorButton->setEnabled(false);
     d->m_closeEditorButton->setProperty("showborder", true);
@@ -161,21 +139,20 @@ EditorToolBar::EditorToolBar(QWidget *parent) :
     d->m_forwardButton->setDefaultAction(d->m_goForwardAction);
 
     d->m_splitButton->setIcon(Utils::Icons::SPLIT_HORIZONTAL_TOOLBAR.icon());
-    d->m_splitButton->setToolTip(tr("Split"));
+    d->m_splitButton->setToolTip(Tr::tr("Split"));
     d->m_splitButton->setPopupMode(QToolButton::InstantPopup);
     d->m_splitButton->setProperty("noArrow", true);
-    QMenu *splitMenu = new QMenu(d->m_splitButton);
+    auto splitMenu = new QMenu(d->m_splitButton);
     splitMenu->addAction(d->m_horizontalSplitAction);
     splitMenu->addAction(d->m_verticalSplitAction);
     splitMenu->addAction(d->m_splitNewWindowAction);
     d->m_splitButton->setMenu(splitMenu);
 
-    d->m_closeSplitButton->setAutoRaise(true);
     d->m_closeSplitButton->setIcon(Utils::Icons::CLOSE_SPLIT_BOTTOM.icon());
 
-    QHBoxLayout *toplayout = new QHBoxLayout(this);
+    auto toplayout = new QHBoxLayout(this);
     toplayout->setSpacing(0);
-    toplayout->setMargin(0);
+    toplayout->setContentsMargins(0, 0, 0, 0);
     toplayout->addWidget(d->m_backButton);
     toplayout->addWidget(d->m_forwardButton);
     toplayout->addWidget(d->m_lockButton);
@@ -190,15 +167,13 @@ EditorToolBar::EditorToolBar(QWidget *parent) :
 
     // this signal is disconnected for standalone toolbars and replaced with
     // a private slot connection
-    connect(d->m_editorList, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
-            this, &EditorToolBar::listSelectionActivated);
-
-    connect(d->m_editorList, &QComboBox::customContextMenuRequested, [this](QPoint p) {
+    connect(d->m_editorList, &QComboBox::activated, this, &EditorToolBar::listSelectionActivated);
+    connect(d->m_editorList, &QComboBox::customContextMenuRequested, this, [this](QPoint p) {
        QMenu menu;
        fillListContextMenu(&menu);
        menu.exec(d->m_editorList->mapToGlobal(p));
     });
-    connect(d->m_dragHandleMenu, &QMenu::aboutToShow, [this]() {
+    connect(d->m_dragHandleMenu, &QMenu::aboutToShow, this, [this] {
        d->m_dragHandleMenu->clear();
        fillListContextMenu(d->m_dragHandleMenu);
     });
@@ -233,17 +208,17 @@ EditorToolBar::~EditorToolBar()
 void EditorToolBar::removeToolbarForEditor(IEditor *editor)
 {
     QTC_ASSERT(editor, return);
-    disconnect(editor->document(), &IDocument::changed, this, &EditorToolBar::checkDocumentStatus);
+    disconnect(editor->document(), &IDocument::changed, this, nullptr);
 
     QWidget *toolBar = editor->toolBar();
-    if (toolBar != 0) {
+    if (toolBar != nullptr) {
         if (d->m_activeToolBar == toolBar) {
             d->m_activeToolBar = d->m_defaultToolBar;
             d->m_activeToolBar->setVisible(true);
         }
         d->m_toolBarPlaceholder->layout()->removeWidget(toolBar);
         toolBar->setVisible(false);
-        toolBar->setParent(0);
+        toolBar->setParent(nullptr);
     }
 }
 
@@ -267,13 +242,13 @@ void EditorToolBar::closeEditor()
 void EditorToolBar::addEditor(IEditor *editor)
 {
     QTC_ASSERT(editor, return);
-    connect(editor->document(), &IDocument::changed, this, &EditorToolBar::checkDocumentStatus);
+    auto document = editor->document();
+    connect(document, &IDocument::changed,
+            this, [this, document] { checkDocumentStatus(document); });
     QWidget *toolBar = editor->toolBar();
 
     if (toolBar && !d->m_isStandalone)
         addCenterToolBar(toolBar);
-
-    updateDocumentStatus(editor->document());
 }
 
 void EditorToolBar::addCenterToolBar(QWidget *toolBar)
@@ -300,12 +275,14 @@ void EditorToolBar::setToolbarCreationFlags(ToolbarCreationFlags flags)
 {
     d->m_isStandalone = flags & FlagsStandalone;
     if (d->m_isStandalone) {
-        connect(EditorManager::instance(), &EditorManager::currentEditorChanged,
-                this, &EditorToolBar::updateEditorListSelection);
+        connect(EditorManager::instance(),
+                &EditorManager::currentEditorChanged,
+                this,
+                &EditorToolBar::setCurrentEditor);
 
-        disconnect(d->m_editorList, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
+        disconnect(d->m_editorList, &QComboBox::activated,
                    this, &EditorToolBar::listSelectionActivated);
-        connect(d->m_editorList, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
+        connect(d->m_editorList, &QComboBox::activated,
                 this, &EditorToolBar::changeActiveEditor);
         d->m_splitButton->setVisible(false);
         d->m_closeSplitButton->setVisible(false);
@@ -319,23 +296,19 @@ void EditorToolBar::setMenuProvider(const EditorToolBar::MenuProvider &provider)
 
 void EditorToolBar::setCurrentEditor(IEditor *editor)
 {
-    IDocument *document = editor ? editor->document() : 0;
-    d->m_editorList->setCurrentIndex(DocumentModel::rowOfDocument(document));
+    IDocument *document = editor ? editor->document() : nullptr;
+    const std::optional<int> index = DocumentModel::rowOfDocument(document);
+    if (QTC_GUARD(index))
+        d->m_editorList->setCurrentIndex(*index);
 
     // If we never added the toolbar from the editor,  we will never change
     // the editor, so there's no need to update the toolbar either.
     if (!d->m_isStandalone)
-        updateToolBar(editor ? editor->toolBar() : 0);
+        updateToolBar(editor ? editor->toolBar() : nullptr);
 
     updateDocumentStatus(document);
 }
 
-void EditorToolBar::updateEditorListSelection(IEditor *newSelection)
-{
-    if (newSelection)
-        d->m_editorList->setCurrentIndex(DocumentModel::rowOfDocument(newSelection->document()));
-}
-
 void EditorToolBar::changeActiveEditor(int row)
 {
     EditorManager::activateEditorForEntry(DocumentModel::entryAtRow(row));
@@ -348,9 +321,11 @@ void EditorToolBar::fillListContextMenu(QMenu *menu)
     } else {
         IEditor *editor = EditorManager::currentEditor();
         DocumentModel::Entry *entry = editor ? DocumentModel::entryForDocument(editor->document())
-                                             : 0;
+                                             : nullptr;
         EditorManager::addSaveAndCloseEditorActions(menu, entry, editor);
         menu->addSeparator();
+        EditorManager::addPinEditorActions(menu, entry);
+        menu->addSeparator();
         EditorManager::addNativeDirAndOpenWithActions(menu, entry);
     }
 }
@@ -373,16 +348,14 @@ void EditorToolBar::setCanGoForward(bool canGoForward)
 
 void EditorToolBar::updateActionShortcuts()
 {
-    d->m_closeEditorButton->setToolTip(ActionManager::command(Constants::CLOSE)->stringWithAppendedShortcut(EditorManager::tr("Close Document")));
+    d->m_closeEditorButton->setToolTip(ActionManager::command(Constants::CLOSE)->stringWithAppendedShortcut(Tr::tr("Close Document")));
     d->m_goBackAction->setToolTip(ActionManager::command(Constants::GO_BACK)->action()->toolTip());
     d->m_goForwardAction->setToolTip(ActionManager::command(Constants::GO_FORWARD)->action()->toolTip());
-    d->m_closeSplitButton->setToolTip(ActionManager::command(Constants::REMOVE_CURRENT_SPLIT)->stringWithAppendedShortcut(tr("Remove Split")));
+    d->m_closeSplitButton->setToolTip(ActionManager::command(Constants::REMOVE_CURRENT_SPLIT)->stringWithAppendedShortcut(Tr::tr("Remove Split")));
 }
 
-void EditorToolBar::checkDocumentStatus()
+void EditorToolBar::checkDocumentStatus(IDocument *document)
 {
-    IDocument *document = qobject_cast<IDocument *>(sender());
-    QTC_ASSERT(document, return);
     DocumentModel::Entry *entry = DocumentModel::entryAtRow(
                 d->m_editorList->currentIndex());
 
@@ -392,7 +365,7 @@ void EditorToolBar::checkDocumentStatus()
 
 void EditorToolBar::updateDocumentStatus(IDocument *document)
 {
-    d->m_closeEditorButton->setEnabled(document != 0);
+    d->m_closeEditorButton->setEnabled(document != nullptr);
 
     if (!document) {
         d->m_lockButton->setIcon(QIcon());
@@ -403,8 +376,6 @@ void EditorToolBar::updateDocumentStatus(IDocument *document)
         return;
     }
 
-    d->m_editorList->setCurrentIndex(DocumentModel::rowOfDocument(document));
-
     if (document->filePath().isEmpty()) {
         d->m_lockButton->setIcon(QIcon());
         d->m_lockButton->setEnabled(false);
@@ -413,18 +384,18 @@ void EditorToolBar::updateDocumentStatus(IDocument *document)
         const static QIcon locked = Utils::Icons::LOCKED_TOOLBAR.icon();
         d->m_lockButton->setIcon(locked);
         d->m_lockButton->setEnabled(true);
-        d->m_lockButton->setToolTip(tr("Make Writable"));
+        d->m_lockButton->setToolTip(Tr::tr("Make Writable"));
     } else {
         const static QIcon unlocked = Utils::Icons::UNLOCKED_TOOLBAR.icon();
         d->m_lockButton->setIcon(unlocked);
         d->m_lockButton->setEnabled(false);
-        d->m_lockButton->setToolTip(tr("File is writable"));
+        d->m_lockButton->setToolTip(Tr::tr("File is writable"));
     }
 
     if (document->filePath().isEmpty())
         d->m_dragHandle->setIcon(QIcon());
     else
-        d->m_dragHandle->setIcon(FileIconProvider::icon(document->filePath().toFileInfo()));
+        d->m_dragHandle->setIcon(Utils::FileIconProvider::icon(document->filePath()));
 
     d->m_editorList->setToolTip(document->filePath().isEmpty()
                                 ? document->displayName()
@@ -455,7 +426,7 @@ bool EditorToolBar::eventFilter(QObject *obj, QEvent *event)
                 return Utils::StyledBar::eventFilter(obj, event);
             auto drag = new QDrag(this);
             auto data = new Utils::DropMimeData;
-            data->addFile(entry->fileName().toString());
+            data->addFile(entry->filePath());
             drag->setMimeData(data);
             Qt::DropAction action = drag->exec(Qt::MoveAction | Qt::CopyAction, Qt::MoveAction);
             if (action == Qt::MoveAction)
