@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "cpasterplugin.h"
 
@@ -116,14 +116,9 @@ CodePasterPlugin::~CodePasterPlugin()
     delete d;
 }
 
-bool CodePasterPlugin::initialize(const QStringList &arguments, QString *errorMessage)
+void CodePasterPlugin::initialize()
 {
-    Q_UNUSED(arguments)
-    Q_UNUSED(errorMessage)
-
     d = new CodePasterPluginPrivate;
-
-    return true;
 }
 
 CodePasterPluginPrivate::CodePasterPluginPrivate()
