@@ -1,56 +1,73 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "debuggersourcepathmappingwidget.h"
+
+#include "debuggeractions.h"
 #include "debuggerengine.h"
+#include "debuggertr.h"
 
 #include <utils/buildablehelperlibrary.h>
 #include <utils/fancylineedit.h>
 #include <utils/hostosinfo.h>
+#include <utils/layoutbuilder.h>
 #include <utils/pathchooser.h>
 #include <utils/qtcassert.h>
-#include <utils/synchronousprocess.h>
+#include <utils/qtcprocess.h>
 #include <utils/variablechooser.h>
 
-#include <QStandardItemModel>
-#include <QTreeView>
+#include <QFileDialog>
+#include <QFormLayout>
+#include <QGroupBox>
+#include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
-#include <QFormLayout>
-#include <QFileDialog>
-#include <QLabel>
+#include <QSettings>
+#include <QStandardItemModel>
+#include <QTreeView>
 
 using namespace Utils;
 
+namespace Debugger::Internal {
+
+class SourcePathMappingModel;
+
 enum { SourceColumn, TargetColumn, ColumnCount };
 
-namespace Debugger {
-namespace Internal {
+using Mapping = QPair<FilePath, FilePath>;
 
-using Mapping = QPair<QString, QString>;
-using SourcePathMap = DebuggerSourcePathMappingWidget::SourcePathMap;
+class DebuggerSourcePathMappingWidget : public QGroupBox
+{
+public:
+    DebuggerSourcePathMappingWidget();
+
+    SourcePathMap sourcePathMap() const;
+    void setSourcePathMap(const SourcePathMap &);
+
+private:
+    void slotAdd();
+    void slotAddQt();
+    void slotRemove();
+    void slotCurrentRowChanged(const QModelIndex &,const QModelIndex &);
+    void slotEditSourceFieldChanged();
+    void slotEditTargetFieldChanged();
+
+    void resizeColumns();
+    void updateEnabled();
+    QString editSourceField() const;
+    QString editTargetField() const;
+    void setEditFieldMapping(const Mapping &m);
+    int currentRow() const;
+    void setCurrentRow(int r);
+
+    SourcePathMappingModel *m_model;
+    QTreeView *m_treeView;
+    QPushButton *m_addButton;
+    QPushButton *m_addQtButton;
+    QPushButton *m_removeButton;
+    QLineEdit *m_sourceLineEdit;
+    Utils::PathChooser *m_targetChooser;
+};
 
 // Qt's various build paths for unpatched versions.
 QStringList qtBuildPaths()
@@ -59,7 +76,8 @@ QStringList qtBuildPaths()
         return {"Q:/qt5_workdir/w/s",
                 "C:/work/build/qt5_workdir/w/s",
                 "c:/users/qt/work/qt",
-                "c:/Users/qt/work/install"};
+                "c:/Users/qt/work/install",
+                "/Users/qt/work/qt"};
     } else if (HostOsInfo::isMacHost()) {
         return { "/Users/qt/work/qt" };
     } else {
@@ -108,12 +126,12 @@ private:
 
 SourcePathMappingModel::SourcePathMappingModel(QObject *parent) :
     QStandardItemModel(0, ColumnCount, parent),
-    m_newSourcePlaceHolder(DebuggerSourcePathMappingWidget::tr("<new source>")),
-    m_newTargetPlaceHolder(DebuggerSourcePathMappingWidget::tr("<new target>"))
+    m_newSourcePlaceHolder(Tr::tr("<new source>")),
+    m_newTargetPlaceHolder(Tr::tr("<new target>"))
 {
     QStringList headers;
-    headers.append(DebuggerSourcePathMappingWidget::tr("Source path"));
-    headers.append(DebuggerSourcePathMappingWidget::tr("Target path"));
+    headers.append(Tr::tr("Source path"));
+    headers.append(Tr::tr("Target path"));
     setHorizontalHeaderLabels(headers);
 }
 
@@ -122,9 +140,9 @@ SourcePathMap SourcePathMappingModel::sourcePathMap() const
     SourcePathMap rc;
     const int rows = rowCount();
     for (int r = 0; r < rows; ++r) {
-        const QPair<QString, QString> m = mappingAt(r); // Skip placeholders.
+        const Mapping m = mappingAt(r); // Skip placeholders.
         if (!m.first.isEmpty() && !m.second.isEmpty())
-            rc.insert(m.first, m.second);
+            rc.insert(m.first.toString(), m.second.toString());
     }
     return rc;
 }
@@ -136,17 +154,17 @@ bool SourcePathMappingModel::isNewPlaceHolder(const Mapping &m) const
     const QChar greaterThan('>');
     return m.first.isEmpty() || m.first.startsWith(lessThan)
            || m.first.endsWith(greaterThan)
-           || m.first == m_newSourcePlaceHolder
+           || m.first.toString() == m_newSourcePlaceHolder
            || m.second.isEmpty() || m.second.startsWith(lessThan)
            || m.second.endsWith(greaterThan)
-           || m.second == m_newTargetPlaceHolder;
+           || m.second.toString() == m_newTargetPlaceHolder;
 }
 
 // Return raw, unfixed mapping
 Mapping SourcePathMappingModel::rawMappingAt(int row) const
 {
-    return Mapping(QDir::fromNativeSeparators(item(row, SourceColumn)->text()),
-                   QDir::fromNativeSeparators(item(row, TargetColumn)->text()));
+    return Mapping(FilePath::fromUserInput(item(row, SourceColumn)->text()),
+                   FilePath::fromUserInput(item(row, TargetColumn)->text()));
 }
 
 // Return mapping, empty if it is the place holder.
@@ -198,18 +216,17 @@ void SourcePathMappingModel::setTarget(int row, const QString &t)
     Path mappings to be applied using source path substitution in GDB.
 */
 
-DebuggerSourcePathMappingWidget::DebuggerSourcePathMappingWidget(QWidget *parent) :
-    QGroupBox(parent),
+DebuggerSourcePathMappingWidget::DebuggerSourcePathMappingWidget() :
     m_model(new SourcePathMappingModel(this)),
     m_treeView(new QTreeView(this)),
-    m_addButton(new QPushButton(tr("Add"), this)),
-    m_addQtButton(new QPushButton(tr("Add Qt sources..."), this)),
-    m_removeButton(new QPushButton(tr("Remove"), this)),
+    m_addButton(new QPushButton(Tr::tr("Add"), this)),
+    m_addQtButton(new QPushButton(Tr::tr("Add Qt sources..."), this)),
+    m_removeButton(new QPushButton(Tr::tr("Remove"), this)),
     m_sourceLineEdit(new QLineEdit(this)),
     m_targetChooser(new PathChooser(this))
 {
-    setTitle(tr("Source Paths Mapping"));
-    setToolTip(tr("<p>Mappings of source file folders to "
+    setTitle(Tr::tr("Source Paths Mapping"));
+    setToolTip(Tr::tr("<p>Mappings of source file folders to "
                   "be used in the debugger can be entered here.</p>"
                   "<p>This is useful when using a copy of the source tree "
                   "at a location different from the one "
@@ -234,7 +251,7 @@ DebuggerSourcePathMappingWidget::DebuggerSourcePathMappingWidget(QWidget *parent
     buttonLayout->addWidget(m_addButton);
     buttonLayout->addWidget(m_addQtButton);
     m_addQtButton->setVisible(!qtBuildPaths().isEmpty());
-    m_addQtButton->setToolTip(tr("<p>Add a mapping for Qt's source folders "
+    m_addQtButton->setToolTip(Tr::tr("<p>Add a mapping for Qt's source folders "
         "when using an unpatched version of Qt."));
     buttonLayout->addWidget(m_removeButton);
     connect(m_addButton, &QAbstractButton::clicked,
@@ -255,20 +272,20 @@ DebuggerSourcePathMappingWidget::DebuggerSourcePathMappingWidget(QWidget *parent
     m_targetChooser->setHistoryCompleter("Debugger.MappingTarget.History");
     connect(m_sourceLineEdit, &QLineEdit::textChanged,
             this, &DebuggerSourcePathMappingWidget::slotEditSourceFieldChanged);
-    connect(m_targetChooser, &PathChooser::pathChanged,
+    connect(m_targetChooser, &PathChooser::textChanged,
             this, &DebuggerSourcePathMappingWidget::slotEditTargetFieldChanged);
     auto editLayout = new QFormLayout;
-    const QString sourceToolTip = tr("<p>The source path contained in the "
+    const QString sourceToolTip = Tr::tr("<p>The source path contained in the "
         "debug information of the executable as reported by the debugger");
-    auto editSourceLabel = new QLabel(tr("&Source path:"));
+    auto editSourceLabel = new QLabel(Tr::tr("&Source path:"));
     editSourceLabel->setToolTip(sourceToolTip);
     m_sourceLineEdit->setToolTip(sourceToolTip);
     editSourceLabel->setBuddy(m_sourceLineEdit);
     editLayout->addRow(editSourceLabel, m_sourceLineEdit);
 
-    const QString targetToolTip = tr("<p>The actual location of the source "
+    const QString targetToolTip = Tr::tr("<p>The actual location of the source "
         "tree on the local machine");
-    auto editTargetLabel = new QLabel(tr("&Target path:"));
+    auto editTargetLabel = new QLabel(Tr::tr("&Target path:"));
     editTargetLabel->setToolTip(targetToolTip);
     editTargetLabel->setBuddy(m_targetChooser);
     m_targetChooser->setToolTip(targetToolTip);
@@ -293,20 +310,19 @@ QString DebuggerSourcePathMappingWidget::editSourceField() const
 
 QString DebuggerSourcePathMappingWidget::editTargetField() const
 {
-    return m_targetChooser->rawPath();
+    return m_targetChooser->rawFilePath().toString();
 }
 
 void DebuggerSourcePathMappingWidget::setEditFieldMapping(const Mapping &m)
 {
-    m_sourceLineEdit->setText(m.first);
-    m_targetChooser->setPath(m.second);
+    m_sourceLineEdit->setText(m.first.toUserOutput());
+    m_targetChooser->setFilePath(m.second);
 }
 
 void DebuggerSourcePathMappingWidget::slotCurrentRowChanged
     (const QModelIndex &current, const QModelIndex &)
 {
-    setEditFieldMapping(current.isValid()
-        ? m_model->mappingAt(current.row()) : Mapping());
+    setEditFieldMapping(current.isValid() ? m_model->mappingAt(current.row()) : Mapping());
     updateEnabled();
 }
 
@@ -365,11 +381,11 @@ void DebuggerSourcePathMappingWidget::slotAdd()
 void DebuggerSourcePathMappingWidget::slotAddQt()
 {
     // Add a mapping for various Qt build locations in case of unpatched builds.
-    const QString qtSourcesPath = QFileDialog::getExistingDirectory(this, tr("Qt Sources"));
+    const FilePath qtSourcesPath = FileUtils::getExistingDirectory(this, Tr::tr("Qt Sources"));
     if (qtSourcesPath.isEmpty())
         return;
     for (const QString &buildPath : qtBuildPaths())
-        m_model->addMapping(buildPath, qtSourcesPath);
+        m_model->addMapping(buildPath, qtSourcesPath.toString());
     resizeColumns();
     setCurrentRow(m_model->rowCount() - 1);
 }
@@ -404,19 +420,10 @@ static QString findQtInstallPath(const FilePath &qmakePath)
 {
     if (qmakePath.isEmpty())
         return QString();
-    QProcess proc;
-    QStringList args;
-    args.append("-query");
-    args.append("QT_INSTALL_HEADERS");
-    proc.start(qmakePath.toString(), args);
-    if (!proc.waitForStarted()) {
-        qWarning("%s: Cannot start '%s': %s", Q_FUNC_INFO, qPrintable(qmakePath.toString()),
-           qPrintable(proc.errorString()));
-        return QString();
-    }
-    proc.closeWriteChannel();
-    if (!proc.waitForFinished() && proc.state() == QProcess::Running) {
-        SynchronousProcess::stopProcess(proc);
+    QtcProcess proc;
+    proc.setCommand({qmakePath, {"-query", "QT_INSTALL_HEADERS"}});
+    proc.start();
+    if (!proc.waitForFinished()) {
         qWarning("%s: Timeout running '%s'.", Q_FUNC_INFO, qPrintable(qmakePath.toString()));
         return QString();
     }
@@ -424,18 +431,15 @@ static QString findQtInstallPath(const FilePath &qmakePath)
         qWarning("%s: '%s' crashed.", Q_FUNC_INFO, qPrintable(qmakePath.toString()));
         return QString();
     }
-    const QByteArray ba = proc.readAllStandardOutput().trimmed();
+    const QByteArray ba = proc.readAllRawStandardOutput().trimmed();
     QDir dir(QString::fromLocal8Bit(ba));
     if (dir.exists() && dir.cdUp())
         return dir.absolutePath();
     return QString();
 }
 
-/* Merge settings for an installed Qt (unless another setting
- * is already in the map. */
-DebuggerSourcePathMappingWidget::SourcePathMap
-    DebuggerSourcePathMappingWidget::mergePlatformQtPath(const DebuggerRunParameters &sp,
-                                                         const SourcePathMap &in)
+/* Merge settings for an installed Qt (unless another setting is already in the map. */
+SourcePathMap mergePlatformQtPath(const DebuggerRunParameters &sp, const SourcePathMap &in)
 {
     const FilePath qmake = BuildableHelperLibrary::findSystemQt(sp.inferior.environment);
     // FIXME: Get this from the profile?
@@ -456,5 +460,104 @@ DebuggerSourcePathMappingWidget::SourcePathMap
     return rc;
 }
 
-} // namespace Internal
-} // namespace Debugger
+//
+// SourcePathMapAspect
+//
+
+class SourcePathMapAspectPrivate
+{
+public:
+    QPointer<DebuggerSourcePathMappingWidget> m_widget;
+};
+
+
+SourcePathMapAspect::SourcePathMapAspect()
+    : d(new SourcePathMapAspectPrivate)
+{
+}
+
+SourcePathMapAspect::~SourcePathMapAspect()
+{
+    delete d;
+}
+
+void SourcePathMapAspect::fromMap(const QVariantMap &)
+{
+    QTC_CHECK(false); // This is only used via read/writeSettings
+}
+
+void SourcePathMapAspect::toMap(QVariantMap &) const
+{
+    QTC_CHECK(false);
+}
+
+void SourcePathMapAspect::addToLayout(Layouting::LayoutBuilder &builder)
+{
+    QTC_CHECK(!d->m_widget);
+    d->m_widget = createSubWidget<DebuggerSourcePathMappingWidget>();
+    d->m_widget->setSourcePathMap(value());
+    builder.addRow(d->m_widget.data());
+}
+
+QVariant SourcePathMapAspect::volatileValue() const
+{
+    QTC_CHECK(!isAutoApply());
+    QTC_ASSERT(d->m_widget, return {});
+    return QVariant::fromValue(d->m_widget->sourcePathMap());
+}
+
+void SourcePathMapAspect::setVolatileValue(const QVariant &val)
+{
+    QTC_CHECK(!isAutoApply());
+    if (d->m_widget)
+        d->m_widget->setSourcePathMap(val.value<SourcePathMap>());
+}
+
+const char sourcePathMappingArrayNameC[] = "SourcePathMappings";
+const char sourcePathMappingSourceKeyC[] = "Source";
+const char sourcePathMappingTargetKeyC[] = "Target";
+
+SourcePathMap SourcePathMapAspect::value() const
+{
+    return BaseAspect::value().value<SourcePathMap>();
+}
+
+void SourcePathMapAspect::writeSettings(QSettings *s) const
+{
+    const SourcePathMap sourcePathMap = value();
+    s->beginWriteArray(sourcePathMappingArrayNameC);
+    if (!sourcePathMap.isEmpty()) {
+        const QString sourcePathMappingSourceKey(sourcePathMappingSourceKeyC);
+        const QString sourcePathMappingTargetKey(sourcePathMappingTargetKeyC);
+        int i = 0;
+        for (auto it = sourcePathMap.constBegin(), cend = sourcePathMap.constEnd();
+             it != cend;
+             ++it, ++i) {
+            s->setArrayIndex(i);
+            s->setValue(sourcePathMappingSourceKey, it.key());
+            s->setValue(sourcePathMappingTargetKey, it.value());
+        }
+    }
+    s->endArray();
+}
+
+void SourcePathMapAspect::readSettings(const QSettings *settings)
+{
+    // Eeks. But legitimate, this operates on ICore::settings();
+    QSettings *s = const_cast<QSettings *>(settings);
+    SourcePathMap sourcePathMap;
+    if (const int count = s->beginReadArray(sourcePathMappingArrayNameC)) {
+        const QString sourcePathMappingSourceKey(sourcePathMappingSourceKeyC);
+        const QString sourcePathMappingTargetKey(sourcePathMappingTargetKeyC);
+        for (int i = 0; i < count; ++i) {
+             s->setArrayIndex(i);
+             const QString key = s->value(sourcePathMappingSourceKey).toString();
+             const QString value = s->value(sourcePathMappingTargetKey).toString();
+             sourcePathMap.insert(key, value);
+        }
+    }
+    s->endArray();
+    setValue(QVariant::fromValue(sourcePathMap));
+}
+
+} // Debugger::Internal
