@@ -1,11 +1,12 @@
 // Copyright (C) 2016 Nicolas Arnaud-Cormos
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "macrooptionspage.h"
 
 #include "macromanager.h"
-#include "macrosconstants.h"
 #include "macrooptionswidget.h"
+#include "macrosconstants.h"
+#include "macrostr.h"
 
 #include <texteditor/texteditorconstants.h>
 
@@ -15,7 +16,7 @@ namespace Internal {
 MacroOptionsPage::MacroOptionsPage()
 {
     setId(Constants::M_OPTIONS_PAGE);
-    setDisplayName(MacroOptionsWidget::tr("Macros"));
+    setDisplayName(Tr::tr("Macros"));
     setCategory(TextEditor::Constants::TEXT_EDITOR_SETTINGS_CATEGORY);
     setWidgetCreator([] { return new MacroOptionsWidget; });
 }
