@@ -1,9 +1,10 @@
 // Copyright (C) 2022 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "mcupackage.h"
 #include "mcusupportversiondetection.h"
 #include "settingshandler.h"
+#include "mcusupporttr.h"
 
 #include <baremetal/baremetalconstants.h>
 #include <coreplugin/icore.h>
@@ -52,9 +53,9 @@ McuPackage::McuPackage(const SettingsHandler::Ptr &settingsHandler,
     , m_addToSystemPath(addToSystemPath)
     , m_valueType(valueType)
 {
-    m_path = FilePath::fromUserInput(qtcEnvironmentVariable(m_environmentVariableName));
-    if (!m_path.exists()) {
-        m_path = this->settingsHandler->getPath(settingsKey, QSettings::UserScope, m_defaultPath);
+    m_path = this->settingsHandler->getPath(settingsKey, QSettings::UserScope, m_defaultPath);
+    if (m_path.isEmpty()) {
+        m_path = FilePath::fromUserInput(qtcEnvironmentVariable(m_environmentVariableName));
     }
 }
 
@@ -182,7 +183,7 @@ void McuPackage::updateStatusUi()
 QString McuPackage::statusText() const
 {
     const QString displayPackagePath = m_path.toUserOutput();
-    const QString displayVersions = m_versions.join(" or ");
+    const QString displayVersions = m_versions.join(Tr::tr(" or "));
     const QString outDetectionPath = m_detectionPath.toUserOutput();
     const QString displayRequiredPath = m_versions.empty() ? outDetectionPath
                                                            : QString("%1 %2").arg(outDetectionPath,
@@ -197,35 +198,35 @@ QString McuPackage::statusText() const
     case Status::ValidPackage:
         response = m_detectionPath.isEmpty()
                        ? (m_detectedVersion.isEmpty()
-                              ? tr("Path %1 exists.").arg(displayPackagePath)
-                              : tr("Path %1 exists. Version %2 was found.")
+                              ? Tr::tr("Path %1 exists.").arg(displayPackagePath)
+                              : Tr::tr("Path %1 exists. Version %2 was found.")
                                     .arg(displayPackagePath, m_detectedVersion))
-                       : tr("Path %1 is valid, %2 was found.")
+                       : Tr::tr("Path %1 is valid, %2 was found.")
                              .arg(displayPackagePath, displayDetectedPath);
         break;
     case Status::ValidPackageMismatchedVersion: {
         const QString versionWarning
             = m_versions.size() == 1
-                  ? tr("but only version %1 is supported").arg(m_versions.first())
-                  : tr("but only versions %1 are supported").arg(displayVersions);
-        response = tr("Path %1 is valid, %2 was found, %3.")
+                  ? Tr::tr("but only version %1 is supported").arg(m_versions.first())
+                  : Tr::tr("but only versions %1 are supported").arg(displayVersions);
+        response = Tr::tr("Path %1 is valid, %2 was found, %3.")
                        .arg(displayPackagePath, displayDetectedPath, versionWarning);
         break;
     }
     case Status::ValidPathInvalidPackage:
-        response = tr("Path %1 exists, but does not contain %2.")
+        response = Tr::tr("Path %1 exists, but does not contain %2.")
                        .arg(displayPackagePath, displayRequiredPath);
         break;
     case Status::InvalidPath:
-        response = tr("Path %1 does not exist.").arg(displayPackagePath);
+        response = Tr::tr("Path %1 does not exist.").arg(displayPackagePath);
         break;
     case Status::EmptyPath:
         response = m_detectionPath.isEmpty()
-                       ? tr("Path is empty.")
-                       : tr("Path is empty, %1 not found.").arg(displayRequiredPath);
+                       ? Tr::tr("Path is empty.")
+                       : Tr::tr("Path is empty, %1 not found.").arg(displayRequiredPath);
         break;
     case Status::ValidPackageVersionNotDetected:
-        response = tr("Path %1 exists, but version %2 could not be detected.")
+        response = Tr::tr("Path %1 exists, but version %2 could not be detected.")
                        .arg(displayPackagePath, displayVersions);
         break;
     }
@@ -243,6 +244,11 @@ bool McuPackage::writeToSettings() const
     return settingsHandler->write(m_settingsKey, m_path, m_defaultPath);
 }
 
+void McuPackage::readFromSettings()
+{
+    setPath(settingsHandler->getPath(m_settingsKey, QSettings::UserScope, m_defaultPath));
+}
+
 QWidget *McuPackage::widget()
 {
     auto *widget = new QWidget;
@@ -250,9 +256,7 @@ QWidget *McuPackage::widget()
     m_fileChooser->setExpectedKind(m_valueType);
     m_fileChooser->lineEdit()->setButtonIcon(FancyLineEdit::Right, Icons::RESET.icon());
     m_fileChooser->lineEdit()->setButtonVisible(FancyLineEdit::Right, true);
-    connect(m_fileChooser->lineEdit(), &FancyLineEdit::rightButtonClicked, this, [&] {
-        m_fileChooser->setFilePath(m_defaultPath);
-    });
+    connect(m_fileChooser->lineEdit(), &FancyLineEdit::rightButtonClicked, this, &McuPackage::reset);
 
     auto layout = new QGridLayout(widget);
     layout->setContentsMargins(0, 0, 0, 0);
@@ -261,7 +265,7 @@ QWidget *McuPackage::widget()
     if (!m_downloadUrl.isEmpty()) {
         auto downLoadButton = new QToolButton(widget);
         downLoadButton->setIcon(Icons::ONLINE.icon());
-        downLoadButton->setToolTip(tr("Download from \"%1\"").arg(m_downloadUrl));
+        downLoadButton->setToolTip(Tr::tr("Download from \"%1\"").arg(m_downloadUrl));
         QObject::connect(downLoadButton, &QToolButton::pressed, this, [this] {
             QDesktopServices::openUrl(m_downloadUrl);
         });
@@ -288,6 +292,43 @@ QWidget *McuPackage::widget()
     return widget;
 }
 
+const QMap<QString, QString> McuPackage::packageLabelTranslations {
+    //Board SDKs
+    {"Board SDK for MIMXRT1050-EVK",                        Tr::tr("Board SDK for MIMXRT1050-EVK")},
+    {"Board SDK MIMXRT1060-EVK",                            Tr::tr("Board SDK MIMXRT1060-EVK")},
+    {"Board SDK for MIMXRT1060-EVK",                        Tr::tr("Board SDK for MIMXRT1060-EVK")},
+    {"Board SDK for MIMXRT1064-EVK",                        Tr::tr("Board SDK for MIMXRT1064-EVK")},
+    {"Board SDK for MIMXRT1170-EVK",                        Tr::tr("Board SDK for MIMXRT1170-EVK")},
+    {"Board SDK for STM32F469I-Discovery",                  Tr::tr("Board SDK for STM32F469I-Discovery")},
+    {"Board SDK for STM32F769I-Discovery",                  Tr::tr("Board SDK for STM32F769I-Discovery")},
+    {"Board SDK for STM32H750B-Discovery",                  Tr::tr("Board SDK for STM32H750B-Discovery")},
+    {"Board SDK",                                           Tr::tr("Board SDK")},
+    {"Flexible Software Package for Renesas RA MCU Family", Tr::tr("Flexible Software Package for Renesas RA MCU Family")},
+    {"Graphics Driver for Traveo II Cluster Series",        Tr::tr("Graphics Driver for Traveo II Cluster Series")},
+    {"Renesas Graphics Library",                            Tr::tr("Renesas Graphics Library")},
+    //Flashing tools
+    {"Cypress Auto Flash Utility",                          Tr::tr("Cypress Auto Flash Utility")},
+    {"MCUXpresso IDE",                                      Tr::tr("MCUXpresso IDE")},
+    {"Path to SEGGER J-Link",                               Tr::tr("Path to SEGGER J-Link")},
+    {"Path to Renesas Flash Programmer",                    Tr::tr("Path to Renesas Flash Programmer")},
+    {"STM32CubeProgrammer",                                 Tr::tr("STM32CubeProgrammer")},
+    //Compilers/Toolchains
+    {"Green Hills Compiler for ARM",                        Tr::tr("Green Hills Compiler for ARM")},
+    {"IAR ARM Compiler",                                    Tr::tr("IAR ARM Compiler")},
+    {"Green Hills Compiler",                                Tr::tr("Green Hills Compiler")},
+    {"GNU Arm Embedded Toolchain",                          Tr::tr("GNU Arm Embedded Toolchain")},
+    {"GNU Toolchain",                                       Tr::tr("GNU Toolchain")},
+    {"MSVC Toolchain",                                      Tr::tr("MSVC Toolchain")},
+    //FreeRTOS
+    {"FreeRTOS SDK for MIMXRT1050-EVK",                     Tr::tr("FreeRTOS SDK for MIMXRT1050-EVK")},
+    {"FreeRTOS SDK for MIMXRT1064-EVK",                     Tr::tr("FreeRTOS SDK for MIMXRT1064-EVK")},
+    {"FreeRTOS SDK for MIMXRT1170-EVK",                     Tr::tr("FreeRTOS SDK for MIMXRT1170-EVK")},
+    {"FreeRTOS SDK for EK-RA6M3G",                          Tr::tr("FreeRTOS SDK for EK-RA6M3G")},
+    {"FreeRTOS SDK for STM32F769I-Discovery",               Tr::tr("FreeRTOS SDK for STM32F769I-Discovery")},
+    //Other
+    {"Path to project for Renesas e2 Studio",               Tr::tr("Path to project for Renesas e2 Studio")}
+};
+
 McuToolChainPackage::McuToolChainPackage(const SettingsHandler::Ptr &settingsHandler,
                                          const QString &label,
                                          const FilePath &defaultPath,
@@ -493,7 +534,7 @@ QVariant McuToolChainPackage::debuggerId() const
     switch (m_type) {
     case ToolChainType::ArmGcc: {
         sub = QString::fromLatin1("bin/arm-none-eabi-gdb-py");
-        displayName = McuPackage::tr("Arm GDB at %1");
+        displayName = Tr::tr("Arm GDB at %1");
         engineType = Debugger::GdbEngineType;
         break;
     }
