@@ -1,30 +1,28 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "perforceeditor.h"
 
 #include "annotationhighlighter.h"
 #include "perforceplugin.h"
+#include "perforcetr.h"
 
 #include <coreplugin/editormanager/editormanager.h>
 #include <utils/qtcassert.h>
 #include <vcsbase/diffandloghighlighter.h>
 
+#include <QAction>
 #include <QDebug>
 #include <QFileInfo>
-#include <QSet>
-#include <QTextStream>
-
-#include <QAction>
 #include <QKeyEvent>
-#include <QLayout>
 #include <QMenu>
+#include <QSet>
+#include <QTextBlock>
 #include <QTextCursor>
 #include <QTextEdit>
-#include <QTextBlock>
+#include <QTextStream>
 
-namespace Perforce {
-namespace Internal {
+namespace Perforce::Internal {
 
 // ------------ PerforceEditor
 PerforceEditorWidget::PerforceEditorWidget() :
@@ -38,7 +36,7 @@ PerforceEditorWidget::PerforceEditorWidget() :
     //    +++ P:/XXX\closingkit\trunk\source\cui\src\cui_core.cpp<tab>2012-02-08 13:54:01.000000000 0100
     setDiffFilePattern("^(?:={4}|\\+{3}) (.+)(?:\\t|#\\d)");
     setLogEntryPattern("^... #\\d change (\\d+) ");
-    setAnnotateRevisionTextFormat(tr("Annotate change list \"%1\""));
+    setAnnotateRevisionTextFormat(Tr::tr("Annotate change list \"%1\""));
     setAnnotationEntryPattern("^(\\d+):");
 }
 
@@ -76,5 +74,4 @@ QStringList PerforceEditorWidget::annotationPreviousVersions(const QString &v) c
     return QStringList(QString::number(changeList - 1));
 }
 
-} // namespace Internal
-} // namespace Perforce
+} // Perforce::Internal
