@@ -1,10 +1,11 @@
 // Copyright (C) 2016 Research In Motion
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "devicecheckbuildstep.h"
 
 #include "../kitinformation.h"
-#include "../target.h"
+#include "../projectexplorertr.h"
+
 #include "devicemanager.h"
 #include "idevice.h"
 #include "idevicefactory.h"
@@ -26,22 +27,22 @@ bool DeviceCheckBuildStep::init()
         Utils::Id deviceTypeId = DeviceTypeKitAspect::deviceTypeId(kit());
         IDeviceFactory *factory = IDeviceFactory::find(deviceTypeId);
         if (!factory || !factory->canCreate()) {
-            emit addOutput(tr("No device configured."), BuildStep::OutputFormat::ErrorMessage);
+            emit addOutput(Tr::tr("No device configured."), BuildStep::OutputFormat::ErrorMessage);
             return false;
         }
 
-        QMessageBox msgBox(QMessageBox::Question, tr("Set Up Device"),
-                              tr("There is no device set up for this kit. Do you want to add a device?"),
+        QMessageBox msgBox(QMessageBox::Question, Tr::tr("Set Up Device"),
+                              Tr::tr("There is no device set up for this kit. Do you want to add a device?"),
                               QMessageBox::Yes|QMessageBox::No);
         msgBox.setDefaultButton(QMessageBox::Yes);
         if (msgBox.exec() == QMessageBox::No) {
-            emit addOutput(tr("No device configured."), BuildStep::OutputFormat::ErrorMessage);
+            emit addOutput(Tr::tr("No device configured."), BuildStep::OutputFormat::ErrorMessage);
             return false;
         }
 
         IDevice::Ptr newDevice = factory->create();
         if (newDevice.isNull()) {
-            emit addOutput(tr("No device configured."), BuildStep::OutputFormat::ErrorMessage);
+            emit addOutput(Tr::tr("No device configured."), BuildStep::OutputFormat::ErrorMessage);
             return false;
         }
 
@@ -66,5 +67,5 @@ Utils::Id DeviceCheckBuildStep::stepId()
 
 QString DeviceCheckBuildStep::displayName()
 {
-    return tr("Check for a configured device");
+    return Tr::tr("Check for a configured device");
 }
