@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -8,6 +8,7 @@
 #include <projectexplorer/runcontrol.h>
 
 #include <utils/portlist.h>
+#include <utils/tasktree.h>
 
 namespace ProjectExplorer {
 
@@ -24,10 +25,11 @@ public:
     DeviceUsedPortsGatherer(QObject *parent = nullptr);
     ~DeviceUsedPortsGatherer() override;
 
-    void start(const IDeviceConstPtr &device);
+    void start();
     void stop();
-    Utils::Port getNextFreePort(Utils::PortList *freePorts) const; // returns -1 if no more are left
+    void setDevice(const IDeviceConstPtr &device);
     QList<Utils::Port> usedPorts() const;
+    QString errorString() const;
 
 signals:
     void error(const QString &errMsg);
@@ -36,17 +38,25 @@ signals:
 private:
     void handleProcessDone();
     void setupUsedPorts();
+    void emitError(const QString &errorString);
 
     Internal::DeviceUsedPortsGathererPrivate * const d;
 };
 
+class PROJECTEXPLORER_EXPORT DeviceUsedPortsGathererAdapter
+    : public Utils::Tasking::TaskAdapter<DeviceUsedPortsGatherer>
+{
+public:
+    DeviceUsedPortsGathererAdapter();
+    void start() final { task()->start(); }
+};
+
 class PROJECTEXPLORER_EXPORT PortsGatherer : public RunWorker
 {
     Q_OBJECT
 
 public:
     explicit PortsGatherer(RunControl *runControl);
-    ~PortsGatherer() override;
 
     QUrl findEndPoint();
 
@@ -59,25 +69,6 @@ private:
     Utils::PortList m_portList;
 };
 
-class PROJECTEXPLORER_EXPORT ChannelForwarder : public RunWorker
-{
-    Q_OBJECT
-
-public:
-    explicit ChannelForwarder(RunControl *runControl);
-
-    using UrlGetter = std::function<QUrl()>;
-    void setFromUrlGetter(const UrlGetter &urlGetter);
-
-    QUrl fromUrl() const { return m_fromUrl; }
-    QUrl toUrl() const { return m_toUrl; }
-
-private:
-    UrlGetter m_fromUrlGetter;
-    QUrl m_fromUrl;
-    QUrl m_toUrl;
-};
-
 class PROJECTEXPLORER_EXPORT ChannelProvider : public RunWorker
 {
     Q_OBJECT
@@ -93,3 +84,5 @@ private:
 };
 
 } // namespace ProjectExplorer
+
+QTC_DECLARE_CUSTOM_TASK(PortGatherer, ProjectExplorer::DeviceUsedPortsGathererAdapter);
