@@ -1,53 +1,43 @@
 // Copyright (C) 2019 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "runcontrol.h"
 
 #include "buildconfiguration.h"
 #include "customparser.h"
-#include "devicesupport/desktopdevice.h"
 #include "devicesupport/devicemanager.h"
 #include "devicesupport/idevice.h"
+#include "devicesupport/idevicefactory.h"
 #include "devicesupport/sshsettings.h"
 #include "kitinformation.h"
 #include "project.h"
 #include "projectexplorer.h"
+#include "projectexplorerconstants.h"
 #include "projectexplorersettings.h"
+#include "projectexplorertr.h"
 #include "runconfigurationaspects.h"
-#include "runcontrol.h"
-#include "session.h"
 #include "target.h"
 #include "windebuginterface.h"
 
-#include <coreplugin/icontext.h>
 #include <coreplugin/icore.h>
 
 #include <utils/algorithm.h>
 #include <utils/checkablemessagebox.h>
-#include <utils/detailswidget.h>
 #include <utils/fileinprojectfinder.h>
-#include <utils/fileutils.h>
 #include <utils/outputformatter.h>
 #include <utils/processinterface.h>
-#include <utils/processinterface.h>
 #include <utils/qtcassert.h>
 #include <utils/qtcprocess.h>
 #include <utils/utilsicons.h>
-#include <utils/variablechooser.h>
 
 #include <coreplugin/icontext.h>
 #include <coreplugin/icore.h>
 
-#include <QDir>
-#include <QFormLayout>
-#include <QHash>
 #include <QLoggingCategory>
 #include <QPushButton>
-#include <QSettings>
 #include <QTextCodec>
 #include <QTimer>
 
-
 #if defined (WITH_JOURNALD)
 #include "journaldwatcher.h"
 #endif
@@ -55,42 +45,22 @@
 using namespace ProjectExplorer::Internal;
 using namespace Utils;
 
-namespace {
-static Q_LOGGING_CATEGORY(statesLog, "qtc.projectmanager.states", QtWarningMsg)
-}
-
 namespace ProjectExplorer {
 
-// RunWorkerFactory
+static Q_LOGGING_CATEGORY(statesLog, "qtc.projectmanager.states", QtWarningMsg)
 
 static QList<RunWorkerFactory *> g_runWorkerFactories;
 
-static QSet<Utils::Id> g_runModes;
-static QSet<Utils::Id> g_runConfigs;
+static QSet<Id> g_runModes;
+static QSet<Id> g_runConfigs;
+
+// RunWorkerFactory
 
 RunWorkerFactory::RunWorkerFactory()
 {
     g_runWorkerFactories.append(this);
 }
 
-RunWorkerFactory::RunWorkerFactory(const WorkerCreator &producer,
-                                   const QList<Utils::Id> &runModes,
-                                   const QList<Utils::Id> &runConfigs,
-                                   const QList<Utils::Id> &deviceTypes)
-        : m_producer(producer),
-          m_supportedRunModes(runModes),
-          m_supportedRunConfigurations(runConfigs),
-          m_supportedDeviceTypes(deviceTypes)
-{
-    g_runWorkerFactories.append(this);
-
-    // Debugging only.
-    for (Utils::Id runMode : runModes)
-        g_runModes.insert(runMode);
-    for (Utils::Id runConfig : runConfigs)
-        g_runConfigs.insert(runConfig);
-}
-
 RunWorkerFactory::~RunWorkerFactory()
 {
     g_runWorkerFactories.removeOne(this);
@@ -101,24 +71,31 @@ void RunWorkerFactory::setProducer(const WorkerCreator &producer)
     m_producer = producer;
 }
 
-void RunWorkerFactory::addSupportedRunMode(Utils::Id runMode)
+void RunWorkerFactory::setSupportedRunConfigs(const QList<Id> &runConfigs)
 {
+    for (Id runConfig : runConfigs)
+        g_runConfigs.insert(runConfig); // Debugging only.
+    m_supportedRunConfigurations = runConfigs;
+}
+
+void RunWorkerFactory::addSupportedRunMode(Id runMode)
+{
+    g_runModes.insert(runMode); // Debugging only.
     m_supportedRunModes.append(runMode);
 }
 
-void RunWorkerFactory::addSupportedRunConfig(Utils::Id runConfig)
+void RunWorkerFactory::addSupportedRunConfig(Id runConfig)
 {
+    g_runConfigs.insert(runConfig); // Debugging only.
     m_supportedRunConfigurations.append(runConfig);
 }
 
-void RunWorkerFactory::addSupportedDeviceType(Utils::Id deviceType)
+void RunWorkerFactory::addSupportedDeviceType(Id deviceType)
 {
     m_supportedDeviceTypes.append(deviceType);
 }
 
-bool RunWorkerFactory::canRun(Utils::Id runMode,
-                              Utils::Id deviceType,
-                              const QString &runConfigId) const
+bool RunWorkerFactory::canCreate(Id runMode, Id deviceType, const QString &runConfigId) const
 {
     if (!m_supportedRunModes.contains(runMode))
         return false;
@@ -128,7 +105,7 @@ bool RunWorkerFactory::canRun(Utils::Id runMode,
         //if (!m_supportedRunConfigurations.contains(runConfigId)
         // return false;
         bool ok = false;
-        for (const Utils::Id &id : m_supportedRunConfigurations) {
+        for (const Id &id : m_supportedRunConfigurations) {
             if (runConfigId.startsWith(id.toString())) {
                 ok = true;
                 break;
@@ -145,21 +122,27 @@ bool RunWorkerFactory::canRun(Utils::Id runMode,
     return true;
 }
 
+RunWorker *RunWorkerFactory::create(RunControl *runControl) const
+{
+    QTC_ASSERT(m_producer, return nullptr);
+    return m_producer(runControl);
+}
+
 void RunWorkerFactory::dumpAll()
 {
-    const QList<Utils::Id> devices =
-            Utils::transform(IDeviceFactory::allDeviceFactories(), &IDeviceFactory::deviceType);
+    const QList<Id> devices =
+            transform(IDeviceFactory::allDeviceFactories(), &IDeviceFactory::deviceType);
 
-    for (Utils::Id runMode : std::as_const(g_runModes)) {
+    for (Id runMode : std::as_const(g_runModes)) {
         qDebug() << "";
-        for (Utils::Id device : devices) {
-            for (Utils::Id runConfig : std::as_const(g_runConfigs)) {
-                const auto check = std::bind(&RunWorkerFactory::canRun,
+        for (Id device : devices) {
+            for (Id runConfig : std::as_const(g_runConfigs)) {
+                const auto check = std::bind(&RunWorkerFactory::canCreate,
                                              std::placeholders::_1,
                                              runMode,
                                              device,
                                              runConfig.toString());
-                const auto factory = Utils::findOrDefault(g_runWorkerFactories, check);
+                const auto factory = findOrDefault(g_runWorkerFactories, check);
                 qDebug() << "MODE:" << runMode << device << runConfig << factory;
             }
         }
@@ -208,41 +191,6 @@ public:
 
     bool canStart() const;
     bool canStop() const;
-    void timerEvent(QTimerEvent *ev) override;
-
-    void killStartWatchdog()
-    {
-        if (startWatchdogTimerId != -1) {
-            killTimer(startWatchdogTimerId);
-            startWatchdogTimerId = -1;
-        }
-    }
-
-    void killStopWatchdog()
-    {
-        if (stopWatchdogTimerId != -1) {
-            killTimer(stopWatchdogTimerId);
-            stopWatchdogTimerId = -1;
-        }
-    }
-
-    void startStartWatchdog()
-    {
-        killStartWatchdog();
-        killStopWatchdog();
-
-        if (startWatchdogInterval != 0)
-            startWatchdogTimerId = startTimer(startWatchdogInterval);
-    }
-
-    void startStopWatchdog()
-    {
-        killStopWatchdog();
-        killStartWatchdog();
-
-        if (stopWatchdogInterval != 0)
-            stopWatchdogTimerId = startTimer(stopWatchdogInterval);
-    }
 
     RunWorker *q;
     RunWorkerState state = RunWorkerState::Initialized;
@@ -252,12 +200,6 @@ public:
     QString id;
 
     QVariantMap data;
-    int startWatchdogInterval = 0;
-    int startWatchdogTimerId = -1;
-    std::function<void()> startWatchdogCallback;
-    int stopWatchdogInterval = 0; // 5000;
-    int stopWatchdogTimerId = -1;
-    std::function<void()> stopWatchdogCallback;
     bool supportsReRunning = true;
     bool essential = false;
 };
@@ -295,12 +237,12 @@ public:
     QString displayName;
     Runnable runnable;
     IDevice::ConstPtr device;
-    Utils::Icon icon;
+    Icon icon;
     const MacroExpander *macroExpander = nullptr;
     AspectContainerData aspectData;
     QString buildKey;
-    QMap<Utils::Id, QVariantMap> settingsData;
-    Utils::Id runConfigId;
+    QMap<Id, QVariantMap> settingsData;
+    Id runConfigId;
     BuildTargetInfo buildTargetInfo;
     FilePath buildDirectory;
     Environment buildEnvironment;
@@ -311,7 +253,7 @@ public:
     std::vector<RunWorkerFactory> m_factories;
 
     // A handle to the actual application process.
-    Utils::ProcessHandle applicationProcessHandle;
+    ProcessHandle applicationProcessHandle;
 
     RunControlState state = RunControlState::Initialized;
 
@@ -323,7 +265,7 @@ class RunControlPrivate : public QObject, public RunControlPrivateData
     Q_OBJECT
 
 public:
-    RunControlPrivate(RunControl *parent, Utils::Id mode)
+    RunControlPrivate(RunControl *parent, Id mode)
         : q(parent), runMode(mode)
     {
         icon = Icons::RUN_SMALL_TOOLBAR;
@@ -365,14 +307,14 @@ public:
     bool supportsReRunning() const;
 
     RunControl *q;
-    Utils::Id runMode;
+    Id runMode;
 };
 
 } // Internal
 
 using namespace Internal;
 
-RunControl::RunControl(Utils::Id mode) :
+RunControl::RunControl(Id mode) :
     d(std::make_unique<RunControlPrivate>(this,  mode))
 {
 }
@@ -450,7 +392,7 @@ void RunControl::setDevice(const IDevice::ConstPtr &device)
                 return;
 
             const QString message = QString::fromUtf8(entry.value("MESSAGE")) + "\n";
-            appendMessage(message, Utils::OutputFormat::LogMessageFormat);
+            appendMessage(message, OutputFormat::LogMessageFormat);
         });
     }
 #endif
@@ -490,22 +432,23 @@ void RunControl::initiateFinish()
     QTimer::singleShot(0, d.get(), &RunControlPrivate::initiateFinish);
 }
 
-RunWorker *RunControl::createWorker(Utils::Id workerId)
+RunWorker *RunControl::createWorker(Id workerId)
 {
-    RunWorkerFactory *factory
-        = Utils::findOrDefault(g_runWorkerFactories, [this, workerId](RunWorkerFactory *factory) {
-              return factory->canRun(workerId, DeviceTypeKitAspect::deviceTypeId(d->kit), QString{});
-          });
-    return factory ? factory->producer()(this) : nullptr;
+    const Id deviceType = DeviceTypeKitAspect::deviceTypeId(d->kit);
+    for (RunWorkerFactory *factory : std::as_const(g_runWorkerFactories)) {
+        if (factory->canCreate(workerId, deviceType, QString()))
+            return factory->create(this);
+    }
+    return nullptr;
 }
 
 bool RunControl::createMainWorker()
 {
     const QList<RunWorkerFactory *> candidates
-        = Utils::filtered(g_runWorkerFactories, [this](RunWorkerFactory *factory) {
-              return factory->canRun(d->runMode,
-                                     DeviceTypeKitAspect::deviceTypeId(d->kit),
-                                     d->runConfigId.toString());
+        = filtered(g_runWorkerFactories, [this](RunWorkerFactory *factory) {
+              return factory->canCreate(d->runMode,
+                                        DeviceTypeKitAspect::deviceTypeId(d->kit),
+                                        d->runConfigId.toString());
           });
 
     // There might be combinations that cannot run. But that should have been checked
@@ -515,13 +458,13 @@ bool RunControl::createMainWorker()
     // There should be at most one top-level producer feeling responsible per combination.
     // Breaking a tie should be done by tightening the restrictions on one of them.
     QTC_CHECK(candidates.size() == 1);
-    return candidates.front()->producer()(this) != nullptr;
+    return candidates.front()->create(this) != nullptr;
 }
 
-bool RunControl::canRun(Utils::Id runMode, Utils::Id deviceType, Utils::Id runConfigId)
+bool RunControl::canRun(Id runMode, Id deviceType, Utils::Id runConfigId)
 {
     for (const RunWorkerFactory *factory : std::as_const(g_runWorkerFactories)) {
-        if (factory->canRun(runMode, deviceType, runConfigId.toString()))
+        if (factory->canCreate(runMode, deviceType, runConfigId.toString()))
             return true;
     }
     return false;
@@ -720,7 +663,7 @@ void RunControlPrivate::onWorkerStarted(RunWorker *worker)
         continueStart();
         return;
     }
-    showError(RunControl::tr("Unexpected run control state %1 when worker %2 started.")
+    showError(Tr::tr("Unexpected run control state %1 when worker %2 started.")
                   .arg(stateName(state))
                   .arg(worker->d->id));
 }
@@ -734,8 +677,7 @@ void RunControlPrivate::onWorkerFailed(RunWorker *worker, const QString &msg)
     case RunControlState::Initialized:
         // FIXME 1: We don't have an output pane yet, so use some other mechanism for now.
         // FIXME 2: Translation...
-        QMessageBox::critical(Core::ICore::dialogParent(),
-             QCoreApplication::translate("TaskHub", "Error"),
+        QMessageBox::critical(Core::ICore::dialogParent(), Tr::tr("Error"),
              QString("Failure during startup. Aborting.") + "<p>" + msg);
         continueStopOrFinish();
         break;
@@ -1042,10 +984,10 @@ bool RunControl::promptToStop(bool *optionalPrompt) const
     if (d->promptToStop)
         return d->promptToStop(optionalPrompt);
 
-    const QString msg = tr("<html><head/><body><center><i>%1</i> is still running.<center/>"
+    const QString msg = Tr::tr("<html><head/><body><center><i>%1</i> is still running.<center/>"
                            "<center>Force it to quit?</center></body></html>").arg(displayName());
-    return showPromptToStopDialog(tr("Application Still Running"), msg,
-                                  tr("Force &Quit"), tr("&Keep Running"),
+    return showPromptToStopDialog(Tr::tr("Application Still Running"), msg,
+                                  Tr::tr("Force &Quit"), Tr::tr("&Keep Running"),
                                   optionalPrompt);
 }
 
@@ -1210,8 +1152,6 @@ namespace Internal {
 
 class SimpleTargetRunnerPrivate : public QObject
 {
-    Q_OBJECT
-
 public:
     explicit SimpleTargetRunnerPrivate(SimpleTargetRunner *parent);
     ~SimpleTargetRunnerPrivate() override;
@@ -1283,7 +1223,7 @@ SimpleTargetRunnerPrivate::SimpleTargetRunnerPrivate(SimpleTargetRunner *parent)
         connect(WinDebugInterface::instance(), &WinDebugInterface::cannotRetrieveDebugOutput,
             this, [this] {
                 disconnect(WinDebugInterface::instance(), nullptr, this, nullptr);
-                q->appendMessage(tr("Cannot retrieve debugging output.")
+                q->appendMessage(Tr::tr("Cannot retrieve debugging output.")
                           + QLatin1Char('\n'), ErrorMessageFormat);
         });
 
@@ -1316,7 +1256,7 @@ void SimpleTargetRunnerPrivate::stop()
         if (m_stopRequested)
             return;
         m_stopRequested = true;
-        q->appendMessage(tr("User requested stop. Shutting down..."), NormalMessageFormat);
+        q->appendMessage(Tr::tr("User requested stop. Shutting down..."), NormalMessageFormat);
         switch (m_state) {
             case Run:
                 m_process.stop();
@@ -1356,7 +1296,7 @@ void SimpleTargetRunnerPrivate::handleDone()
 
 void SimpleTargetRunnerPrivate::handleStandardOutput()
 {
-    const QByteArray data = m_process.readAllStandardOutput();
+    const QByteArray data = m_process.readAllRawStandardOutput();
     const QString msg = m_outputCodec->toUnicode(
                 data.constData(), data.length(), &m_outputCodecState);
     q->appendMessageChunk(msg, StdOutFormat);
@@ -1364,7 +1304,7 @@ void SimpleTargetRunnerPrivate::handleStandardOutput()
 
 void SimpleTargetRunnerPrivate::handleStandardError()
 {
-    const QByteArray data = m_process.readAllStandardError();
+    const QByteArray data = m_process.readAllRawStandardError();
     const QString msg = m_outputCodec->toUnicode(
                 data.constData(), data.length(), &m_errorCodecState);
     q->appendMessageChunk(msg, StdErrFormat);
@@ -1397,7 +1337,7 @@ void SimpleTargetRunnerPrivate::start()
 
     const IDevice::ConstPtr device = DeviceManager::deviceForPath(m_command.executable());
     if (device && !device->isEmptyCommandAllowed() && m_command.isEmpty()) {
-        m_resultData.m_errorString = tr("Cannot run: No command given.");
+        m_resultData.m_errorString = Tr::tr("Cannot run: No command given.");
         m_resultData.m_error = QProcess::FailedToStart;
         m_resultData.m_exitStatus = QProcess::CrashExit;
         forwardDone();
@@ -1447,11 +1387,11 @@ void SimpleTargetRunnerPrivate::forwardDone()
     if (m_stopReported)
         return;
     const QString executable = m_command.executable().displayName();
-    QString msg = tr("%1 exited with code %2").arg(executable).arg(m_resultData.m_exitCode);
+    QString msg = Tr::tr("%1 exited with code %2").arg(executable).arg(m_resultData.m_exitCode);
     if (m_resultData.m_exitStatus == QProcess::CrashExit)
-        msg = tr("%1 crashed.").arg(executable);
+        msg = Tr::tr("%1 crashed.").arg(executable);
     else if (m_stopForced)
-        msg = tr("The process was ended forcefully.");
+        msg = Tr::tr("The process was ended forcefully.");
     else if (m_resultData.m_error != QProcess::UnknownError)
         msg = RunWorker::userMessageForProcessError(m_resultData.m_error, m_command.executable());
     q->appendMessage(msg, NormalMessageFormat);
@@ -1496,12 +1436,12 @@ void SimpleTargetRunner::start()
     d->m_process.setTerminalMode(useTerminal ? Utils::TerminalMode::On : Utils::TerminalMode::Off);
     d->m_runAsRoot = runAsRoot;
 
-    const QString msg = RunControl::tr("Starting %1...").arg(d->m_command.displayName());
+    const QString msg = Tr::tr("Starting %1...").arg(d->m_command.displayName());
     appendMessage(msg, NormalMessageFormat);
 
     const bool isDesktop = !d->m_command.executable().needsDevice();
     if (isDesktop && d->m_command.isEmpty()) {
-        reportFailure(RunControl::tr("No executable specified."));
+        reportFailure(Tr::tr("No executable specified."));
         return;
     }
     d->start();
@@ -1580,28 +1520,6 @@ bool RunWorkerPrivate::canStop() const
     return true;
 }
 
-void RunWorkerPrivate::timerEvent(QTimerEvent *ev)
-{
-    if (ev->timerId() == startWatchdogTimerId) {
-        if (startWatchdogCallback) {
-            killStartWatchdog();
-            startWatchdogCallback();
-        } else {
-            q->reportFailure(RunWorker::tr("Worker start timed out."));
-        }
-        return;
-    }
-    if (ev->timerId() == stopWatchdogTimerId) {
-        if (stopWatchdogCallback) {
-            killStopWatchdog();
-            stopWatchdogCallback();
-        } else {
-            q->reportFailure(RunWorker::tr("Worker stop timed out."));
-        }
-        return;
-    }
-}
-
 /*!
     \class ProjectExplorer::RunWorker
 
@@ -1651,7 +1569,6 @@ RunWorker::~RunWorker() = default;
  */
 void RunWorker::initiateStart()
 {
-    d->startStartWatchdog();
     d->runControl->d->debugMessage("Initiate start for " + d->id);
     start();
 }
@@ -1664,7 +1581,6 @@ void RunWorker::initiateStart()
  */
 void RunWorker::reportStarted()
 {
-    d->killStartWatchdog();
     d->runControl->d->onWorkerStarted(this);
     emit started();
 }
@@ -1677,7 +1593,6 @@ void RunWorker::reportStarted()
  */
 void RunWorker::initiateStop()
 {
-    d->startStopWatchdog();
     d->runControl->d->debugMessage("Initiate stop for " + d->id);
     stop();
 }
@@ -1693,7 +1608,6 @@ void RunWorker::initiateStop()
  */
 void RunWorker::reportStopped()
 {
-    d->killStopWatchdog();
     d->runControl->d->onWorkerStopped(this);
     emit stopped();
 }
@@ -1707,8 +1621,6 @@ void RunWorker::reportStopped()
  */
 void RunWorker::reportDone()
 {
-    d->killStartWatchdog();
-    d->killStopWatchdog();
     switch (d->state) {
         case RunWorkerState::Initialized:
             QTC_CHECK(false);
@@ -1734,8 +1646,6 @@ void RunWorker::reportDone()
  */
 void RunWorker::reportFailure(const QString &msg)
 {
-    d->killStartWatchdog();
-    d->killStopWatchdog();
     d->runControl->d->onWorkerFailed(this, msg);
 }
 
@@ -1781,18 +1691,6 @@ void RunWorker::setId(const QString &id)
     d->id = id;
 }
 
-void RunWorker::setStartTimeout(int ms, const std::function<void()> &callback)
-{
-    d->startWatchdogInterval = ms;
-    d->startWatchdogCallback = callback;
-}
-
-void RunWorker::setStopTimeout(int ms, const std::function<void()> &callback)
-{
-    d->stopWatchdogInterval = ms;
-    d->stopWatchdogCallback = callback;
-}
-
 void RunWorker::recordData(const QString &channel, const QVariant &data)
 {
     d->data[channel] = data;
@@ -1815,16 +1713,16 @@ bool RunWorker::supportsReRunning() const
 
 QString RunWorker::userMessageForProcessError(QProcess::ProcessError error, const FilePath &program)
 {
-    QString failedToStart = tr("The process failed to start.");
-    QString msg = tr("An unknown error in the process occurred.");
+    QString failedToStart = Tr::tr("The process failed to start.");
+    QString msg = Tr::tr("An unknown error in the process occurred.");
     switch (error) {
         case QProcess::FailedToStart:
-            msg = failedToStart + ' ' + tr("Either the "
+            msg = failedToStart + ' ' + Tr::tr("Either the "
                 "invoked program \"%1\" is missing, or you may have insufficient "
                 "permissions to invoke the program.").arg(program.toUserOutput());
             break;
         case QProcess::Crashed:
-            msg = tr("The process crashed.");
+            msg = Tr::tr("The process crashed.");
             break;
         case QProcess::Timedout:
             // "The last waitFor...() function timed out. "
@@ -1832,12 +1730,12 @@ QString RunWorker::userMessageForProcessError(QProcess::ProcessError error, cons
             // "waitFor...() again."
             return QString(); // sic!
         case QProcess::WriteError:
-            msg = tr("An error occurred when attempting to write "
+            msg = Tr::tr("An error occurred when attempting to write "
                 "to the process. For example, the process may not be running, "
                 "or it may have closed its input channel.");
             break;
         case QProcess::ReadError:
-            msg = tr("An error occurred when attempting to read from "
+            msg = Tr::tr("An error occurred when attempting to read from "
                 "the process. For example, the process may not be running.");
             break;
         case QProcess::UnknownError:
@@ -1893,6 +1791,15 @@ void OutputFormatterFactory::setFormatterCreator(const FormatterCreator &creator
     m_creator = creator;
 }
 
+// SimpleTargetRunnerFactory
+
+SimpleTargetRunnerFactory::SimpleTargetRunnerFactory(const QList<Id> &runConfigs)
+{
+    setProduct<SimpleTargetRunner>();
+    addSupportedRunMode(ProjectExplorer::Constants::NORMAL_RUN_MODE);
+    setSupportedRunConfigs(runConfigs);
+}
+
 } // namespace ProjectExplorer
 
 #include "runcontrol.moc"
