@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "taskmodel.h"
 
@@ -29,12 +7,16 @@
 #include "task.h"
 #include "taskhub.h"
 
+#include <utils/algorithm.h>
 #include <utils/qtcassert.h>
 
 #include <QFileInfo>
 #include <QFontMetrics>
 
 #include <algorithm>
+#include <functional>
+
+using namespace std::placeholders;
 
 namespace ProjectExplorer {
 namespace Internal {
@@ -78,11 +60,12 @@ bool TaskModel::hasFile(const QModelIndex &index) const
     return !m_tasks.at(row).file.isEmpty();
 }
 
-void TaskModel::addCategory(Utils::Id categoryId, const QString &categoryName)
+void TaskModel::addCategory(Utils::Id categoryId, const QString &categoryName, int priority)
 {
     QTC_ASSERT(categoryId.isValid(), return);
     CategoryData data;
     data.displayName = categoryName;
+    data.priority = priority;
     m_categories.insert(categoryId, data);
 }
 
@@ -92,16 +75,27 @@ Tasks TaskModel::tasks(Utils::Id categoryId) const
         return m_tasks;
 
     Tasks taskList;
-    foreach (const Task &t, m_tasks) {
+    for (const Task &t : std::as_const(m_tasks)) {
         if (t.category == categoryId)
             taskList.append(t);
     }
     return taskList;
 }
 
-bool sortById(const Task &task, unsigned int id)
+bool TaskModel::compareTasks(const Task &task1, const Task &task2)
 {
-    return task.taskId < id;
+    if (task1.category == task2.category)
+        return task1.taskId < task2.taskId;
+
+    // Higher-priority task should appear higher up in the view and thus compare less-than.
+    const int prio1 = m_categories.value(task1.category).priority;
+    const int prio2 = m_categories.value(task2.category).priority;
+    if (prio1 < prio2)
+        return false;
+    if (prio1 > prio2)
+        return true;
+
+    return task1.taskId < task2.taskId;
 }
 
 void TaskModel::addTask(const Task &task)
@@ -110,7 +104,8 @@ void TaskModel::addTask(const Task &task)
     CategoryData &data = m_categories[task.category];
     CategoryData &global = m_categories[Utils::Id()];
 
-    auto it = std::lower_bound(m_tasks.begin(), m_tasks.end(),task.taskId, sortById);
+    auto it = std::lower_bound(m_tasks.begin(), m_tasks.end(), task,
+                               std::bind(&TaskModel::compareTasks, this,  _1, task));
     int i = it - m_tasks.begin();
     beginInsertRows(QModelIndex(), i, i);
     m_tasks.insert(it, task);
@@ -134,30 +129,31 @@ void TaskModel::removeTask(unsigned int id)
     }
 }
 
-int TaskModel::rowForId(unsigned int id)
+int TaskModel::rowForTask(const Task &task)
 {
-    auto it = std::lower_bound(m_tasks.constBegin(), m_tasks.constEnd(), id, sortById);
+    auto it = std::lower_bound(m_tasks.constBegin(), m_tasks.constEnd(), task,
+                               std::bind(&TaskModel::compareTasks, this, _1, task));
     if (it == m_tasks.constEnd())
         return -1;
     return it - m_tasks.constBegin();
 }
 
-void TaskModel::updateTaskFileName(unsigned int id, const QString &fileName)
+void TaskModel::updateTaskFileName(const Task &task, const QString &fileName)
 {
-    int i = rowForId(id);
+    int i = rowForTask(task);
     QTC_ASSERT(i != -1, return);
-    if (m_tasks.at(i).taskId == id) {
+    if (m_tasks.at(i).taskId == task.taskId) {
         m_tasks[i].file = Utils::FilePath::fromString(fileName);
         const QModelIndex itemIndex = index(i, 0);
         emit dataChanged(itemIndex, itemIndex);
     }
 }
 
-void TaskModel::updateTaskLineNumber(unsigned int id, int line)
+void TaskModel::updateTaskLineNumber(const Task &task, int line)
 {
-    int i = rowForId(id);
+    int i = rowForTask(task);
     QTC_ASSERT(i != -1, return);
-    if (m_tasks.at(i).taskId == id) {
+    if (m_tasks.at(i).taskId == task.taskId) {
         m_tasks[i].movedLine = line;
         const QModelIndex itemIndex = index(i, 0);
         emit dataChanged(itemIndex, itemIndex);
@@ -269,6 +265,13 @@ Task TaskModel::task(const QModelIndex &index) const
     return m_tasks.at(row);
 }
 
+Tasks TaskModel::tasks(const QModelIndexList &indexes) const
+{
+    return Utils::filtered(
+                Utils::transform<Tasks>(indexes, [this](const QModelIndex &i) { return task(i); }),
+                [](const Task &t) { return !t.isNull(); });
+}
+
 QList<Utils::Id> TaskModel::categoryIds() const
 {
     QList<Utils::Id> categories = m_categories.keys();
@@ -343,6 +346,12 @@ void TaskFilterModel::setFilterIncludesWarnings(bool b)
     invalidateFilter();
 }
 
+Tasks TaskFilterModel::tasks(const QModelIndexList &indexes) const
+{
+    return taskModel()->tasks(Utils::transform(indexes, [this](const QModelIndex &i) {
+        return mapToSource(i); }));
+}
+
 int TaskFilterModel::issuesCount(int startRow, int endRow) const
 {
     int count = 0;
