@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "abstractaction.h"
 
@@ -38,9 +38,21 @@ void AbstractAction::updateContext()
     if (m_selectionContext.isValid()) {
         m_defaultAction->setEnabled(isEnabled(m_selectionContext));
         m_defaultAction->setVisible(isVisible(m_selectionContext));
+        if (m_defaultAction->isCheckable())
+            m_defaultAction->setChecked(isChecked(m_selectionContext));
     }
 }
 
+bool AbstractAction::isChecked(const SelectionContext &) const
+{
+    return false;
+}
+
+void AbstractAction::setCheckable(bool checkable)
+{
+    m_defaultAction->setCheckable(checkable);
+}
+
 DefaultAction *AbstractAction::defaultAction() const
 {
     return m_defaultAction.data();
