@@ -1,33 +1,16 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 #pragma once
 
+#include <qmldesignercomponents_global.h>
+
 #include <abstractview.h>
 
+#include <QPicture>
+
 #include <functional>
 #include <memory>
+#include <vector>
 
 QT_BEGIN_NAMESPACE
 class QGraphicsScene;
@@ -53,12 +36,12 @@ class DragTool;
 class ItemLibraryEntry;
 class QmlItemNode;
 
-class QMLDESIGNERCORE_EXPORT FormEditorView : public AbstractView
+class QMLDESIGNERCOMPONENTS_EXPORT FormEditorView : public AbstractView
 {
     Q_OBJECT
 
 public:
-    FormEditorView(QObject *parent = nullptr);
+    FormEditorView(ExternalDependenciesInterface &externalDependencies);
     ~FormEditorView() override;
 
     // AbstractView
@@ -112,9 +95,11 @@ public:
     void changeToCustomTool();
     void changeCurrentToolTo(AbstractFormEditorTool *customTool);
 
-    void registerTool(AbstractCustomTool *tool);
+    void registerTool(std::unique_ptr<AbstractCustomTool> &&tool);
 
-    void auxiliaryDataChanged(const ModelNode &node, const PropertyName &name, const QVariant &data) override;
+    void auxiliaryDataChanged(const ModelNode &node,
+                              AuxiliaryDataKeyView name,
+                              const QVariant &data) override;
 
     void instancesCompleted(const QVector<ModelNode> &completedNodeList) override;
     void instanceInformationsChanged(const QMultiHash<ModelNode, InformationName> &informationChangedHash) override;
@@ -146,13 +131,16 @@ private:
     void setupFormEditorItemTree(const QmlItemNode &qmlItemNode);
     void removeNodeFromScene(const QmlItemNode &qmlItemNode);
     void createFormEditorWidget();
-    void temporaryBlockView(int duration = 1000);
+    void temporaryBlockView(int duration = 100);
     void resetNodeInstanceView();
     void addOrRemoveFormEditorItem(const ModelNode &node);
+    void checkRootModelNode();
+    void setupFormEditor3DView();
+    void setupRootItemSize();
 
     QPointer<FormEditorWidget> m_formEditorWidget;
     QPointer<FormEditorScene> m_scene;
-    QList<AbstractCustomTool*> m_customToolList;
+    std::vector<std::unique_ptr<AbstractCustomTool>> m_customTools;
     std::unique_ptr<MoveTool> m_moveTool;
     std::unique_ptr<SelectionTool> m_selectionTool;
     std::unique_ptr<RotationTool> m_rotationTool;
