@@ -1,41 +1,23 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include "qmldesignercorelib_global.h"
 #include "abstractview.h"
+#include "modelcache.h"
 
 #include <modelnode.h>
 #include <nodeinstance.h>
 #include <nodeinstanceclientinterface.h>
 #include <nodeinstanceserverinterface.h>
 
+#include <utils/filepath.h>
+
 #include <QElapsedTimer>
 #include <QHash>
 #include <QImage>
+#include <QPixmap>
 #include <QPointer>
 #include <QRectF>
 #include <QTime>
@@ -50,6 +32,10 @@ namespace ProjectExplorer {
 class Target;
 }
 
+namespace Utils {
+class QtcProcess;
+}
+
 namespace QmlDesigner {
 
 class NodeInstanceServerProxy;
@@ -68,6 +54,7 @@ class CompleteComponentCommand;
 class InformationContainer;
 class TokenCommand;
 class ConnectionManagerInterface;
+class ExternalDependenciesInterface;
 
 class QMLDESIGNERCORE_EXPORT NodeInstanceView : public AbstractView, public NodeInstanceClientInterface
 {
@@ -78,7 +65,8 @@ class QMLDESIGNERCORE_EXPORT NodeInstanceView : public AbstractView, public Node
 public:
     using Pointer = QWeakPointer<NodeInstanceView>;
 
-    explicit NodeInstanceView(ConnectionManagerInterface &connectionManager);
+    explicit NodeInstanceView(ConnectionManagerInterface &connectionManager,
+                              ExternalDependenciesInterface &externalDependencies);
     ~NodeInstanceView() override;
 
     void modelAttached(Model *model) override;
@@ -97,7 +85,9 @@ public:
     void nodeIdChanged(const ModelNode& node, const QString& newId, const QString& oldId) override;
     void nodeOrderChanged(const NodeListProperty &listProperty) override;
     void importsChanged(const QList<Import> &addedImports, const QList<Import> &removedImports) override;
-    void auxiliaryDataChanged(const ModelNode &node, const PropertyName &name, const QVariant &data) override;
+    void auxiliaryDataChanged(const ModelNode &node,
+                              AuxiliaryDataKeyView key,
+                              const QVariant &data) override;
     void customNotification(const AbstractView *view, const QString &identifier, const QList<ModelNode> &nodeList, const QList<QVariant> &data) override;
     void nodeSourceChanged(const ModelNode &modelNode, const QString &newNodeSource) override;
     void capturedData(const CapturedDataCommand &capturedData) override;
@@ -108,8 +98,8 @@ public:
     NodeInstance instanceForModelNode(const ModelNode &node) const ;
     bool hasInstanceForModelNode(const ModelNode &node) const;
 
-    NodeInstance instanceForId(qint32 id);
-    bool hasInstanceForId(qint32 id);
+    NodeInstance instanceForId(qint32 id) const;
+    bool hasInstanceForId(qint32 id) const;
 
     QRectF sceneRect() const;
 
@@ -140,20 +130,31 @@ public:
                               const QList<ModelNode> &lastSelectedNodeList) override;
 
     void sendInputEvent(QInputEvent *e) const;
-    void view3DAction(const View3DActionCommand &command);
-    void requestModelNodePreviewImage(const ModelNode &node, const ModelNode &renderNode);
+    void view3DAction(View3DActionType type, const QVariant &value) override;
+    void requestModelNodePreviewImage(const ModelNode &node, const ModelNode &renderNode) const;
     void edit3DViewResized(const QSize &size) const;
 
     void handlePuppetToCreatorCommand(const PuppetToCreatorCommand &command) override;
 
-    QVariant previewImageDataForGenericNode(const ModelNode &modelNode, const ModelNode &renderNode);
-    QVariant previewImageDataForImageNode(const ModelNode &modelNode);
+    QVariant previewImageDataForGenericNode(const ModelNode &modelNode,
+                                            const ModelNode &renderNode) const;
+    QVariant previewImageDataForImageNode(const ModelNode &modelNode) const;
 
     void setCrashCallback(std::function<void()> crashCallback)
     {
         m_crashCallback = std::move(crashCallback);
     }
 
+    void setCaptureImageMinimumAndMaximumSize(QSize captureImageMinimumSize,
+                                              QSize captureImageMaximumSize)
+    {
+        m_captureImageMinimumSize = captureImageMinimumSize;
+        m_captureImageMaximumSize = captureImageMaximumSize;
+    }
+
+    void startNanotrace();
+    void endNanotrace();
+
 protected:
     void timerEvent(QTimerEvent *event) override;
 
@@ -166,6 +167,8 @@ private: // functions
 
     NodeInstance loadNode(const ModelNode &node);
 
+    void clearErrors();
+
     void removeAllInstanceNodeRelationships();
 
     void removeRecursiveChildRelationship(const ModelNode &removedNode);
@@ -219,27 +222,48 @@ private: // functions
         QString id;
         QString info;
     };
-    QVariant modelNodePreviewImageDataToVariant(const ModelNodePreviewImageData &imageData);
+    QVariant modelNodePreviewImageDataToVariant(const ModelNodePreviewImageData &imageData) const;
     void updatePreviewImageForNode(const ModelNode &modelNode, const QImage &image);
 
     void updateWatcher(const QString &path);
-
+    void handleShaderChanges();
+    void handleQsbProcessExit(Utils::QtcProcess *qsbProcess, const QString &shader);
+    void updateQsbPathToFilterMap();
     void updateRotationBlocks();
     void maybeResetOnPropertyChange(const PropertyName &name, const ModelNode &node,
                                     PropertyChangeFlags flags);
 
 private:
-    QHash<QString, ModelNodePreviewImageData> m_imageDataMap;
+    struct NodeInstanceCacheData
+    {
+        NodeInstanceCacheData(const QHash<ModelNode, NodeInstance> &i,
+                              const QHash<ModelNode, QImage> &p)
+            : instances(i)
+            , previewImages(p)
+        {}
+
+        NodeInstanceCacheData() = default;
+
+        QHash<ModelNode, NodeInstance> instances;
+        QHash<ModelNode, QImage> previewImages;
+    };
+
+    QList<NodeInstance> loadInstancesFromCache(const QList<ModelNode> &nodeList,
+                                               const NodeInstanceCacheData &cache);
+
+    mutable QHash<QString, ModelNodePreviewImageData> m_imageDataMap;
 
     NodeInstance m_rootNodeInstance;
     NodeInstance m_activeStateInstance;
     QHash<ModelNode, NodeInstance> m_nodeInstanceHash;
+    ModelCache<NodeInstanceCacheData> m_nodeInstanceCache;
     QHash<ModelNode, QImage> m_statePreviewImage;
     ConnectionManagerInterface &m_connectionManager;
+    ExternalDependenciesInterface &m_externalDependencies;
     std::unique_ptr<NodeInstanceServerProxy> m_nodeInstanceServer;
     QImage m_baseStatePreviewImage;
     QElapsedTimer m_lastCrashTime;
-    ProjectExplorer::Target *m_currentTarget = nullptr;
+    QPointer<ProjectExplorer::Target> m_currentTarget;
     int m_restartProcessTimerId;
     RewriterTransaction m_puppetTransaction;
 
@@ -254,8 +278,15 @@ private:
     QFileSystemWatcher *m_fileSystemWatcher;
     QTimer m_resetTimer;
     QTimer m_updateWatcherTimer;
+    QTimer m_generateQsbFilesTimer;
+    Utils::FilePath m_qsbPath;
     QSet<QString> m_pendingUpdateDirs;
+    QHash<QString, bool> m_qsbTargets; // Value indicates if target is pending qsb generation
+    QHash<QString, QStringList> m_qsbPathToFilterMap;
+    int m_remainingQsbTargets = 0;
     QTimer m_rotBlockTimer;
+    QSize m_captureImageMinimumSize{150, 150};
+    QSize m_captureImageMaximumSize{1000, 1000};
 };
 
 } // namespace ProxyNodeInstanceView
