@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "modelnode.h"
 
@@ -889,6 +889,11 @@ bool ModelNode::hasBindingProperty(const PropertyName &name) const
     return hasProperty(name) && m_internalNode->property(name)->isBindingProperty();
 }
 
+bool ModelNode::hasSignalHandlerProperty(const PropertyName &name) const
+{
+    return hasProperty(name) && m_internalNode->property(name)->isSignalHandlerProperty();
+}
+
 bool ModelNode::hasNodeAbstractProperty(const PropertyName &name) const
 {
     return hasProperty(name) && m_internalNode->property(name)->isNodeAbstractProperty();
@@ -1308,6 +1313,95 @@ bool ModelNode::isThisOrAncestorLocked(const ModelNode &node)
     return isThisOrAncestorLocked(node.parentProperty().parentModelNode());
 }
 
+/*!
+ * \brief The lowest common ancestor node for node1 and node2. If one of the nodes (Node A) is
+ * the ancestor of the other node, the return value is Node A and not the parent of Node A.
+ * \param node1 First node
+ * \param node2 Second node
+ * \param depthOfLCA Depth of the return value
+ * \param depthOfNode1 Depth of node1. Use this parameter for optimization
+ * \param depthOfNode2 Depth of node2. Use this parameter for optimization
+ */
+static ModelNode lowestCommonAncestor(const ModelNode &node1,
+                                      const ModelNode &node2,
+                                      int &depthOfLCA,
+                                      const int &depthOfNode1 = -1,
+                                      const int &depthOfNode2 = -1)
+{
+    Q_ASSERT(node1.isValid() && node2.isValid());
+
+    auto depthOfNode = [] (const ModelNode &node) -> int {
+        int depth = 0;
+        ModelNode parentNode = node;
+        while (!parentNode.isRootNode()) {
+            depth++;
+            parentNode = parentNode.parentProperty().parentModelNode();
+        }
+        return depth;
+    };
+
+    if (node1 == node2) {
+        depthOfLCA = (depthOfNode1 < 0)
+                ? ((depthOfNode2 < 0) ? depthOfNode(node1) : depthOfNode2)
+                : depthOfNode1;
+        return node1;
+    }
+
+    if (node1.isRootNode()) {
+        depthOfLCA = 0;
+        return node1;
+    }
+
+    if (node2.isRootNode()) {
+        depthOfLCA = 0;
+        return node2;
+    }
+
+    ModelNode nodeLower = node1;
+    ModelNode nodeHigher = node2;
+    int depthLower = (depthOfNode1 < 0) ? depthOfNode(nodeLower) : depthOfNode1;
+    int depthHigher = (depthOfNode2 < 0) ? depthOfNode(nodeHigher) :depthOfNode2;
+
+    if (depthLower > depthHigher) {
+        std::swap(depthLower, depthHigher);
+        std::swap(nodeLower, nodeHigher);
+    }
+
+    int depthDiff = depthHigher - depthLower;
+    while (depthDiff--)
+        nodeHigher = nodeHigher.parentProperty().parentModelNode();
+
+    while (nodeLower != nodeHigher) {
+        nodeLower = nodeLower.parentProperty().parentModelNode();
+        nodeHigher = nodeHigher.parentProperty().parentModelNode();
+        --depthLower;
+    }
+
+    depthOfLCA = depthLower;
+    return nodeLower;
+}
+
+/*!
+ * \brief The lowest common node containing all nodes. If one of the nodes (Node A) is
+ * the ancestor of the other nodes, the return value is Node A and not the parent of Node A.
+ */
+ModelNode ModelNode::lowestCommonAncestor(const QList<ModelNode> &nodes)
+{
+    if (nodes.isEmpty())
+        return {};
+
+    ModelNode accumulatedNode = nodes.first();
+    int accumulatedNodeDepth = -1;
+    for (const ModelNode &node : Utils::span<const ModelNode>(nodes).subspan(1)) {
+        accumulatedNode = QmlDesigner::lowestCommonAncestor(accumulatedNode,
+                                                            node,
+                                                            accumulatedNodeDepth,
+                                                            accumulatedNodeDepth);
+    }
+
+    return accumulatedNode;
+}
+
 void  ModelNode::setScriptFunctions(const QStringList &scriptFunctionList)
 {
     model()->d->setScriptFunctions(m_internalNode, scriptFunctionList);
