@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "filefilteritems.h"
 
@@ -33,12 +11,11 @@
 #include <QDebug>
 #include <QDir>
 #include <QImageReader>
-#include <QRegExp>
+#include <QRegularExpression>
 
 namespace QmlProjectManager {
 
-FileFilterBaseItem::FileFilterBaseItem(QObject *parent) :
-        QmlProjectContentItem(parent)
+FileFilterBaseItem::FileFilterBaseItem()
 {
     m_updateFileListTimer.setSingleShot(true);
     m_updateFileListTimer.setInterval(50);
@@ -100,7 +77,7 @@ void FileFilterBaseItem::setFilter(const QString &filter)
     m_regExpList.clear();
     m_fileSuffixes.clear();
 
-    foreach (const QString &pattern, filter.split(QLatin1Char(';'))) {
+    for (const QString &pattern : filter.split(QLatin1Char(';'))) {
         if (pattern.isEmpty())
             continue;
         // decide if it's a canonical pattern like *.x
@@ -113,7 +90,7 @@ void FileFilterBaseItem::setFilter(const QString &filter)
                 continue;
             }
         }
-        m_regExpList << QRegExp(pattern, Qt::CaseInsensitive, QRegExp::Wildcard);
+        m_regExpList << QRegularExpression(QRegularExpression::wildcardToRegularExpression(pattern));
     }
 
     updateFileList();
@@ -171,7 +148,7 @@ QStringList FileFilterBaseItem::files() const
   */
 bool FileFilterBaseItem::matchesFile(const QString &filePath) const
 {
-    foreach (const QString &explicitFile, m_explicitFiles) {
+    for (const QString &explicitFile : m_explicitFiles) {
         if (absolutePath(explicitFile) == filePath)
             return true;
     }
@@ -182,7 +159,7 @@ bool FileFilterBaseItem::matchesFile(const QString &filePath) const
         return false;
 
     const QDir fileDir = QFileInfo(filePath).absoluteDir();
-    foreach (const QString &watchedDirectory, watchedDirectories()) {
+    for (const QString &watchedDirectory : watchedDirectories()) {
         if (QDir(watchedDirectory) == fileDir)
             return true;
     }
@@ -225,9 +202,9 @@ void FileFilterBaseItem::updateFileListNow()
 
     QSet<QString> dirsToBeWatched;
     QSet<QString> newFiles;
-    foreach (const QString &explicitPath, m_explicitFiles) {
+    for (const QString &explicitPath : std::as_const(m_explicitFiles))
         newFiles << absolutePath(explicitPath);
-    }
+
     if ((!m_fileSuffixes.isEmpty() || !m_regExpList.isEmpty()) && m_explicitFiles.isEmpty())
         newFiles += filesInSubTree(QDir(m_defaultDir), QDir(projectDir), &dirsToBeWatched);
 
@@ -258,13 +235,13 @@ void FileFilterBaseItem::updateFileListNow()
 
 bool FileFilterBaseItem::fileMatches(const QString &fileName) const
 {
-    foreach (const QString &suffix, m_fileSuffixes) {
+    for (const QString &suffix : std::as_const(m_fileSuffixes)) {
         if (fileName.endsWith(suffix, Qt::CaseInsensitive))
             return true;
     }
 
-    foreach (QRegExp filter, m_regExpList) {
-        if (filter.exactMatch(fileName))
+    for (const QRegularExpression &filter : std::as_const(m_regExpList)) {
+        if (filter.match(fileName).hasMatch())
             return true;
     }
 
@@ -278,7 +255,7 @@ QSet<QString> FileFilterBaseItem::filesInSubTree(const QDir &rootDir, const QDir
     if (parsedDirs)
         parsedDirs->insert(dir.absolutePath());
 
-    foreach (const QFileInfo &file, dir.entryInfoList(QDir::Files)) {
+    for (const QFileInfo &file : dir.entryInfoList(QDir::Files)) {
         const QString fileName = file.fileName();
 
         if (fileMatches(fileName))
@@ -286,27 +263,26 @@ QSet<QString> FileFilterBaseItem::filesInSubTree(const QDir &rootDir, const QDir
     }
 
     if (recursive()) {
-        foreach (const QFileInfo &subDir, dir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot)) {
+        for (const QFileInfo &subDir : dir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot)) {
             fileSet += filesInSubTree(rootDir, QDir(subDir.absoluteFilePath()), parsedDirs);
         }
     }
     return fileSet;
 }
 
-ImageFileFilterItem::ImageFileFilterItem(QObject *parent)
-    : FileFilterBaseItem(parent)
+ImageFileFilterItem::ImageFileFilterItem()
 {
     QString filter;
     // supported image formats according to
     QList<QByteArray> extensions = QImageReader::supportedImageFormats();
-    foreach (const QByteArray &extension, extensions) {
+    extensions.append("hdr");
+    extensions.append("ktx");
+    for (const QByteArray &extension : std::as_const(extensions))
         filter.append(QString::fromLatin1("*.%1;").arg(QString::fromLatin1(extension)));
-    }
     setFilter(filter);
 }
 
-FileFilterItem::FileFilterItem(const QString &fileFilter, QObject *parent)
-    : FileFilterBaseItem(parent)
+FileFilterItem::FileFilterItem(const QString &fileFilter)
 {
     setFilter(fileFilter);
 }
