@@ -1,9 +1,10 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "gettingstartedwelcomepage.h"
 
 #include "exampleslistmodel.h"
+#include "examplesparser.h"
 #include "qtsupporttr.h"
 
 #include <coreplugin/coreconstants.h>
@@ -46,6 +47,8 @@ namespace Internal {
 
 const char C_FALLBACK_ROOT[] = "ProjectsFallbackRoot";
 
+Q_GLOBAL_STATIC(ExampleSetModel, s_exampleSetModel)
+
 ExamplesWelcomePage::ExamplesWelcomePage(bool showExamples)
     : m_showExamples(showExamples)
 {
@@ -66,16 +69,18 @@ Id ExamplesWelcomePage::id() const
     return m_showExamples ? "Examples" : "Tutorials";
 }
 
-QString ExamplesWelcomePage::copyToAlternativeLocation(const QFileInfo& proFileInfo, QStringList &filesToOpen, const QStringList& dependencies)
+FilePath ExamplesWelcomePage::copyToAlternativeLocation(const FilePath &proFile,
+                                                        FilePaths &filesToOpen,
+                                                        const FilePaths &dependencies)
 {
-    const QString projectDir = proFileInfo.canonicalPath();
+    const FilePath projectDir = proFile.canonicalPath().parentDir();
     QDialog d(ICore::dialogParent());
     auto lay = new QGridLayout(&d);
     auto descrLbl = new QLabel;
     d.setWindowTitle(Tr::tr("Copy Project to writable Location?"));
     descrLbl->setTextFormat(Qt::RichText);
     descrLbl->setWordWrap(false);
-    const QString nativeProjectDir = QDir::toNativeSeparators(projectDir);
+    const QString nativeProjectDir = projectDir.toUserOutput();
     descrLbl->setText(QString::fromLatin1("<blockquote>%1</blockquote>").arg(nativeProjectDir));
     descrLbl->setMinimumWidth(descrLbl->sizeHint().width());
     descrLbl->setWordWrap(true);
@@ -92,9 +97,10 @@ QString ExamplesWelcomePage::copyToAlternativeLocation(const QFileInfo& proFileI
     txt->setBuddy(chooser);
     chooser->setExpectedKind(PathChooser::ExistingDirectory);
     chooser->setHistoryCompleter(QLatin1String("Qt.WritableExamplesDir.History"));
-    const QString defaultRootDirectory = DocumentManager::projectsDirectory().toString();
+    const FilePath defaultRootDirectory = DocumentManager::projectsDirectory();
     QtcSettings *settings = ICore::settings();
-    chooser->setFilePath(FilePath::fromVariant(settings->value(C_FALLBACK_ROOT, defaultRootDirectory)));
+    chooser->setFilePath(
+        FilePath::fromSettings(settings->value(C_FALLBACK_ROOT, defaultRootDirectory.toVariant())));
     lay->addWidget(txt, 1, 0);
     lay->addWidget(chooser, 1, 1);
     enum { Copy = QDialog::Accepted + 1, Keep = QDialog::Accepted + 2 };
@@ -108,90 +114,86 @@ QString ExamplesWelcomePage::copyToAlternativeLocation(const QFileInfo& proFileI
     connect(chooser, &PathChooser::validChanged, copyBtn, &QWidget::setEnabled);
     int code = d.exec();
     if (code == Copy) {
-        QString exampleDirName = proFileInfo.dir().dirName();
-        QString destBaseDir = chooser->filePath().toString();
+        const QString exampleDirName = projectDir.fileName();
+        const FilePath destBaseDir = chooser->filePath();
         settings->setValueWithDefault(C_FALLBACK_ROOT, destBaseDir, defaultRootDirectory);
-        QDir toDirWithExamplesDir(destBaseDir);
-        if (toDirWithExamplesDir.cd(exampleDirName)) {
-            toDirWithExamplesDir.cdUp(); // step out, just to not be in the way
+        const FilePath targetDir = destBaseDir / exampleDirName;
+        if (targetDir.exists()) {
             QMessageBox::warning(ICore::dialogParent(),
                                  Tr::tr("Cannot Use Location"),
                                  Tr::tr("The specified location already exists. "
                                         "Please specify a valid location."),
                                  QMessageBox::Ok,
                                  QMessageBox::NoButton);
-            return QString();
+            return {};
         } else {
-            QString error;
-            QString targetDir = destBaseDir + QLatin1Char('/') + exampleDirName;
-            if (FileUtils::copyRecursively(FilePath::fromString(projectDir),
-                    FilePath::fromString(targetDir), &error)) {
-                // set vars to new location
-                const QStringList::Iterator end = filesToOpen.end();
-                for (QStringList::Iterator it = filesToOpen.begin(); it != end; ++it)
-                    it->replace(projectDir, targetDir);
+            expected_str<void> result = projectDir.copyRecursively(targetDir);
 
-                foreach (const QString &dependency, dependencies) {
-                    const FilePath targetFile = FilePath::fromString(targetDir)
-                            .pathAppended(QDir(dependency).dirName());
-                    if (!FileUtils::copyRecursively(FilePath::fromString(dependency), targetFile,
-                            &error)) {
+            if (result) {
+                // set vars to new location
+                const FilePaths::Iterator end = filesToOpen.end();
+                for (FilePaths::Iterator it = filesToOpen.begin(); it != end; ++it) {
+                    const FilePath relativePath = it->relativeChildPath(projectDir);
+                    *it = targetDir.resolvePath(relativePath);
+                }
+
+                for (const FilePath &dependency : dependencies) {
+                    const FilePath targetFile = targetDir.pathAppended(dependency.fileName());
+                    result = dependency.copyRecursively(targetFile);
+                    if (!result) {
                         QMessageBox::warning(ICore::dialogParent(),
                                              Tr::tr("Cannot Copy Project"),
-                                             error);
+                                             result.error());
                         // do not fail, just warn;
                     }
                 }
 
-
-                return targetDir + QLatin1Char('/') + proFileInfo.fileName();
+                return targetDir / proFile.fileName();
             } else {
-                QMessageBox::warning(ICore::dialogParent(), Tr::tr("Cannot Copy Project"), error);
+                QMessageBox::warning(ICore::dialogParent(),
+                                     Tr::tr("Cannot Copy Project"),
+                                     result.error());
             }
-
         }
     }
     if (code == Keep)
-        return proFileInfo.absoluteFilePath();
-    return QString();
+        return proFile.absoluteFilePath();
+    return {};
 }
 
 void ExamplesWelcomePage::openProject(const ExampleItem *item)
 {
     using namespace ProjectExplorer;
-    QString proFile = item->projectPath;
+    FilePath proFile = item->projectPath;
     if (proFile.isEmpty())
         return;
 
-    QStringList filesToOpen = item->filesToOpen;
+    FilePaths filesToOpen = item->filesToOpen;
     if (!item->mainFile.isEmpty()) {
         // ensure that the main file is opened on top (i.e. opened last)
         filesToOpen.removeAll(item->mainFile);
         filesToOpen.append(item->mainFile);
     }
 
-    QFileInfo proFileInfo(proFile);
-    if (!proFileInfo.exists())
+    if (!proFile.exists())
         return;
 
     // If the Qt is a distro Qt on Linux, it will not be writable, hence compilation will fail
     // Same if it is installed in non-writable location for other reasons
-    const bool needsCopy = withNtfsPermissions<bool>([proFileInfo] {
-        QFileInfo pathInfo(proFileInfo.path());
-        return !proFileInfo.isWritable()
-                || !pathInfo.isWritable() /* path of .pro file */
-                || !QFileInfo(pathInfo.path()).isWritable() /* shadow build directory */;
+    const bool needsCopy = withNtfsPermissions<bool>([proFile] {
+        return !proFile.isWritableFile()
+               || !proFile.parentDir().isWritableDir() /* path of project file */
+               || !proFile.parentDir().parentDir().isWritableDir() /* shadow build directory */;
     });
     if (needsCopy)
-        proFile = copyToAlternativeLocation(proFileInfo, filesToOpen, item->dependencies);
+        proFile = copyToAlternativeLocation(proFile, filesToOpen, item->dependencies);
 
     // don't try to load help and files if loading the help request is being cancelled
     if (proFile.isEmpty())
         return;
-    ProjectExplorerPlugin::OpenProjectResult result =
-            ProjectExplorerPlugin::openProject(FilePath::fromString(proFile));
+    ProjectExplorerPlugin::OpenProjectResult result = ProjectExplorerPlugin::openProject(proFile);
     if (result) {
-        ICore::openFiles(FileUtils::toFilePathList(filesToOpen));
+        ICore::openFiles(filesToOpen);
         ModeManager::activateMode(Core::Constants::MODE_EDIT);
         QUrl docUrl = QUrl::fromUserInput(item->docUrl);
         if (docUrl.isValid())
@@ -258,10 +260,6 @@ public:
         : m_isExamples(isExamples)
     {
         m_exampleDelegate.setShowExamples(isExamples);
-        static auto s_examplesModel = new ExamplesListModel(this);
-        m_examplesModel = s_examplesModel;
-
-        auto filteredModel = new ExamplesListModelFilter(m_examplesModel, !m_isExamples, this);
 
         auto searchBox = new SearchBox(this);
         m_searcher = searchBox->m_lineEdit;
@@ -284,13 +282,16 @@ public:
             exampleSetSelector->setPalette(pal);
             exampleSetSelector->setMinimumWidth(Core::ListItemDelegate::GridItemWidth);
             exampleSetSelector->setMaximumWidth(Core::ListItemDelegate::GridItemWidth);
-            ExampleSetModel *exampleSetModel = m_examplesModel->exampleSetModel();
-            exampleSetSelector->setModel(exampleSetModel);
-            exampleSetSelector->setCurrentIndex(exampleSetModel->selectedExampleSet());
-            connect(exampleSetSelector, &QComboBox::activated,
-                    exampleSetModel, &ExampleSetModel::selectExampleSet);
-            connect(exampleSetModel, &ExampleSetModel::selectedExampleSetChanged,
-                    exampleSetSelector, &QComboBox::setCurrentIndex);
+            exampleSetSelector->setModel(s_exampleSetModel);
+            exampleSetSelector->setCurrentIndex(s_exampleSetModel->selectedExampleSet());
+            connect(exampleSetSelector,
+                    &QComboBox::activated,
+                    s_exampleSetModel,
+                    &ExampleSetModel::selectExampleSet);
+            connect(s_exampleSetModel,
+                    &ExampleSetModel::selectedExampleSetChanged,
+                    exampleSetSelector,
+                    &QComboBox::setCurrentIndex);
 
             hbox->setSpacing(Core::WelcomePageHelpers::HSpacing);
             hbox->addWidget(exampleSetSelector);
@@ -302,17 +303,15 @@ public:
         grid->addWidget(searchBar, 0, 1);
         grid->addWidget(WelcomePageHelpers::panelBar(this), 0, 2);
 
-        auto gridView = new GridView(this);
-        gridView->setModel(filteredModel);
+        auto gridView = new SectionedGridView(this);
+        new ExamplesViewController(s_exampleSetModel, gridView, isExamples, this);
+
         gridView->setItemDelegate(&m_exampleDelegate);
-        if (auto sb = gridView->verticalScrollBar())
-            sb->setSingleStep(25);
         grid->addWidget(gridView, 1, 1, 1, 2);
 
         connect(&m_exampleDelegate, &ExampleDelegate::tagClicked,
                 this, &ExamplesPageWidget::onTagClicked);
-        connect(m_searcher, &QLineEdit::textChanged,
-                filteredModel, &ExamplesListModelFilter::setSearchString);
+        connect(m_searcher, &QLineEdit::textChanged, gridView, &SectionedGridView::setSearchString);
     }
 
     void onTagClicked(const QString &tag)
@@ -324,7 +323,6 @@ public:
 
     const bool m_isExamples;
     ExampleDelegate m_exampleDelegate;
-    QPointer<ExamplesListModel> m_examplesModel;
     QLineEdit *m_searcher;
 };
 
