@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "callgrindparser.h"
 
@@ -226,7 +204,7 @@ void Parser::Private::parse(const FilePath &filePath)
 
     // functions that need to accumulate their calees
     QSet<Function *> pendingFunctions;
-    for (const CallData &callData : qAsConst(pendingCallees)) {
+    for (const CallData &callData : std::as_const(pendingCallees)) {
         Function *calledFunction = nullptr;
         QTC_ASSERT(callData.call, continue);
         QTC_ASSERT(callData.call->caller(), continue);
@@ -265,7 +243,7 @@ void Parser::Private::parse(const FilePath &filePath)
     // lookup done
 
     // now accumulate callees
-    for (Function *func : qAsConst(pendingFunctions))
+    for (Function *func : std::as_const(pendingFunctions))
         func->finalize();
 
     emit q->parserDataReady();
@@ -342,11 +320,11 @@ Parser::Private::NamePair Parser::Private::parseName(const char *begin, const ch
     if (*current == '(') {
         current++;
         if ((nameShorthand = parseNameShorthand(&current, end)) == -1)
-            return qMakePair(qint64(-1), QString()); // error
+            return {qint64(-1), {}}; // error
     }
 
     skipSpace(&current, end);
-    return qMakePair(nameShorthand, QString::fromUtf8(QByteArray(current, end - current)));
+    return {nameShorthand, QString::fromUtf8(QByteArray(current, end - current))};
 }
 
 /*
