@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "callgrindvisualisation.h"
 
@@ -155,7 +155,7 @@ void FunctionGraphicsItem::paint(QPainter *painter,
     painter->save();
 
     QRectF rect = this->rect();
-    const QColor &color = brush().color();
+    const QColor color = brush().color();
     if (option->state & QStyle::State_Selected) {
         QLinearGradient gradient(0, 0, rect.width(), 0);
         gradient.setColorAt(0, color.darker(100));
