@@ -53,9 +53,7 @@
 namespace qbs {
 using namespace Internal;
 
-Command::~Command()
-{
-}
+Command::~Command() = default;
 
 void Command::parse(QStringList &input)
 {
@@ -210,6 +208,7 @@ static QList<CommandLineOption::Type> resolveOptions()
             CommandLineOption::DryRunOptionType,
             CommandLineOption::ForceProbesOptionType,
             CommandLineOption::LogTimeOptionType,
+            CommandLineOption::DeprecationWarningsOptionType,
             CommandLineOption::DisableFallbackProviderType};
 }
 
